/* This file is automatically generated by i386-gen.  Do not edit!  */
/* Copyright (C) 2007-2025 Free Software Foundation, Inc.

   This file is part of the GNU opcodes library.

   This library is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3, or (at your option)
   any later version.

   It is distributed in the hope that it will be useful, but WITHOUT
   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
   or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
   License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston,
   MA 02110-1301, USA.  */

extern const char i386_mnemonics[];

#define MN_ud0 0x1
#define MN_prefetcht0 0x5
#define MN_prefetchit0 0x10
#define MN_t2rpntlvwz0 0x1c
#define MN_xsha1 0x28
#define MN_fld1 0x2e
#define MN_ud1 0x33
#define MN_sha1msg1 0x37
#define MN_vsha512msg1 0x40
#define MN_vsm3msg1 0x4c
#define MN_sha256msg1 0x55
#define MN_fprem1 0x60
#define MN_f2xm1 0x67
#define MN_fyl2xp1 0x6d
#define MN_t2rpntlvwz0t1 0x75
#define MN_t2rpntlvwz1t1 0x83
#define MN_tileloaddt1 0x91
#define MN_prefetcht1 0x9d
#define MN_prefetchit1 0xa8
#define MN_pfrcpit1 0xb4
#define MN_pfrsqit1 0xbd
#define MN_int1 0xc6
#define MN_t2rpntlvwz0rst1 0xcb
#define MN_t2rpntlvwz1rst1 0xdb
#define MN_tileloaddrst1 0xeb
#define MN_prefetchwt1 0xf9
#define MN_t2rpntlvwz1 0x105
#define MN_xsha512 0x111
#define MN_vmovdqa32 0x119
#define MN_data32 0x123
#define MN_crc32 0x12a
#define MN_endbr32 0x130
#define MN_addr32 0x138
#define MN_vmovdqu32 0x13f
#define MN_ud2 0x149
#define MN_fldlg2 0x14d
#define MN_xrng2 0x154
#define MN_sha1msg2 0x15a
#define MN_vsha512msg2 0x163
#define MN_vsm3msg2 0x16f
#define MN_sha256msg2 0x178
#define MN_push2 0x183
#define MN_montmul2 0x189
#define MN_sm2 0x192
#define MN_fldln2 0x196
#define MN_pop2 0x19d
#define MN_vsha512rnds2 0x1a2
#define MN_vsm3rnds2 0x1af
#define MN_sha256rnds2 0x1b9
#define MN_prefetcht2 0x1c5
#define MN_pfrcpit2 0x1d0
#define MN_prefetchrst2 0x1d9
#define MN_vbroadcastf32x2 0x1e6
#define MN_vbroadcasti32x2 0x1f6
#define MN_vshuff64x2 0x206
#define MN_vextractf64x2 0x211
#define MN_vinsertf64x2 0x21f
#define MN_vbroadcastf64x2 0x22c
#define MN_vshufi64x2 0x23c
#define MN_vextracti64x2 0x247
#define MN_vinserti64x2 0x255
#define MN_vbroadcasti64x2 0x262
#define MN_sm3 0x272
#define MN_int3 0x276
#define MN_vmovdqa64 0x27b
#define MN_xsavec64 0x285
#define MN_xsave64 (MN_fxsave64 + 1)
#define MN_fxsave64 0x28e
#define MN_endbr64 0x297
#define MN_xrstor64 (MN_fxrstor64 + 1)
#define MN_fxrstor64 0x29f
#define MN_xsaves64 0x2a9
#define MN_xrstors64 0x2b2
#define MN_xsaveopt64 0x2bc
#define MN_vmovdqu64 0x2c7
#define MN_rex64 0x2d1
#define MN_xsha384 0x2d7
#define MN_sm4 0x2df
#define MN_sha1rnds4 0x2e3
#define MN_vsm4rnds4 0x2ed
#define MN_vshuff32x4 0x2f7
#define MN_vextractf32x4 0x302
#define MN_vinsertf32x4 0x310
#define MN_vbroadcastf32x4 0x31d
#define MN_vshufi32x4 0x32d
#define MN_vextracti32x4 0x338
#define MN_vinserti32x4 0x346
#define MN_vbroadcasti32x4 0x353
#define MN_vextractf64x4 0x363
#define MN_vinsertf64x4 0x371
#define MN_vbroadcastf64x4 0x37e
#define MN_vextracti64x4 0x38e
#define MN_vinserti64x4 0x39c
#define MN_vbroadcasti64x4 0x3a9
#define MN_vsm4key4 0x3b9
#define MN_data16 0x3c2
#define MN_vfmsub231bf16 0x3c9
#define MN_vfnmsub231bf16 0x3d7
#define MN_vfmadd231bf16 0x3e6
#define MN_vfnmadd231bf16 0x3f4
#define MN_vfmsub132bf16 0x403
#define MN_vfnmsub132bf16 0x411
#define MN_vfmadd132bf16 0x420
#define MN_vfnmadd132bf16 0x42e
#define MN_vcvtne2ps2bf16 0x43d
#define MN_vcvtneps2bf16 0x44c
#define MN_vfmsub213bf16 0x45a
#define MN_vfnmsub213bf16 0x468
#define MN_vfmadd213bf16 0x477
#define MN_vfnmadd213bf16 0x485
#define MN_vsubbf16 0x494
#define MN_vaddbf16 0x49d
#define MN_vreducebf16 0x4a6
#define MN_vrndscalebf16 0x4b2
#define MN_vscalefbf16 0x4c0
#define MN_vmulbf16 0x4cc
#define MN_vminbf16 0x4d5
#define MN_vrcpbf16 0x4de
#define MN_vcmpbf16 0x4e7
#define MN_vgetexpbf16 0x4f0
#define MN_vcomisbf16 0x4fc
#define MN_vfpclassbf16 0x507
#define MN_vgetmantbf16 0x514
#define MN_vrsqrtbf16 0x521
#define MN_vsqrtbf16 0x52c
#define MN_vdivbf16 0x536
#define MN_vminmaxbf16 0x53f
#define MN_vmaxbf16 0x54b
#define MN_tconjtfp16 0x554
#define MN_addr16 0x55f
#define MN_vmovdqu16 0x566
#define MN_xsha256 0x570
#define MN_encodekey256 0x578
#define MN_vperm2f128 0x585
#define MN_vextractf128 0x590
#define MN_vinsertf128 0x59d
#define MN_vbroadcastf128 0x5a9
#define MN_vperm2i128 0x5b8
#define MN_vextracti128 0x5c3
#define MN_vinserti128 0x5d0
#define MN_vbroadcasti128 0x5dc
#define MN_encodekey128 0x5eb
#define MN_vcvt2ph2bf8 0x5f8
#define MN_vcvtbiasph2bf8 0x604
#define MN_vcvtph2bf8 0x613
#define MN_vcvt2ph2hf8 0x61e
#define MN_vcvtbiasph2hf8 0x62a
#define MN_vcvtph2hf8 0x639
#define MN_vmovdqu8 0x644
#define MN_vextractf32x8 0x64d
#define MN_vinsertf32x8 0x65b
#define MN_vbroadcastf32x8 0x668
#define MN_vextracti32x8 0x678
#define MN_vinserti32x8 0x686
#define MN_vbroadcasti32x8 0x693
#define MN_ud2a 0x6a3
#define MN_aaa 0x6a8
#define MN_daa 0x6ac
#define MN_ssca 0x6b0
#define MN_lea 0x6b5
#define MN_invlpga 0x6b9
#define MN_pusha 0x6c1
#define MN_ja 0x6c7
#define MN_jna 0x6ca
#define MN_ccmpna 0x6ce
#define MN_setna 0x6d5
#define MN_ctestna 0x6db
#define MN_setzuna 0x6e3
#define MN_cmovna (MN_fcmovna + 1)
#define MN_fcmovna (MN_cfcmovna + 1)
#define MN_cfcmovna 0x6eb
#define MN_ccmpa 0x6f4
#define MN_popa 0x6fa
#define MN_movntdqa (MN_vmovntdqa + 1)
#define MN_vmovntdqa 0x6ff
#define MN_movdqa (MN_vmovdqa + 1)
#define MN_vmovdqa 0x709
#define MN_seta 0x711
#define MN_prefetchnta 0x716
#define MN_ctesta 0x722
#define MN_setzua 0x729
#define MN_cmova (MN_fcmova + 1)
#define MN_fcmova (MN_cfcmova + 1)
#define MN_cfcmova 0x730
#define MN_rex_b 0x738
#define MN_ud2b 0x73e
#define MN_vpermi2b 0x743
#define MN_vpmovm2b 0x74c
#define MN_vpermt2b 0x755
#define MN_movdir64b 0x75e
#define MN_cmpxchg16b 0x768
#define MN_cmpxchg8b 0x773
#define MN_vpshab 0x77d
#define MN_sbb 0x784
#define MN_psubb (MN_vpsubb + 1)
#define MN_vpsubb 0x788
#define MN_xcrypt_ecb 0x78f
#define MN_xcryptecb 0x79a
#define MN_llwpcb 0x7a4
#define MN_slwpcb 0x7ab
#define MN_kaddb 0x7b2
#define MN_paddb (MN_vpaddb + 1)
#define MN_vpaddb 0x7b8
#define MN_kandb 0x7bf
#define MN_vpexpandb 0x7c5
#define MN_vpmovusdb 0x7cf
#define MN_vpmovsdb 0x7d9
#define MN_vpmovdb 0x7e2
#define MN_vpcomgeb 0x7ea
#define MN_vpcomleb 0x7f3
#define MN_vpcmpnleb 0x7fc
#define MN_vpcmpleb 0x806
#define MN_vpcomfalseb 0x80f
#define MN_vpcomtrueb 0x81b
#define MN_xcrypt_cfb 0x826
#define MN_xcryptcfb 0x831
#define MN_xcrypt_ofb 0x83b
#define MN_xcryptofb 0x846
#define MN_pshufb (MN_vpshufb + 1)
#define MN_vpshufb 0x850
#define MN_invlpgb 0x858
#define MN_pavgb (MN_vpavgb + 1)
#define MN_vpavgb 0x860
#define MN_jb 0x867
#define MN_pbndkb 0x86a
#define MN_pmovmskb (MN_vpmovmskb + 1)
#define MN_vpmovmskb 0x871
#define MN_vpshlb 0x87b
#define MN_kshiftlb 0x882
#define MN_gf2p8mulb (MN_vgf2p8mulb + 1)
#define MN_vgf2p8mulb 0x88b
#define MN_vpblendmb 0x896
#define MN_vptestnmb 0x8a0
#define MN_vpcomb 0x8aa
#define MN_vpshufbitqmb 0x8b1
#define MN_vpermb 0x8be
#define MN_vptestmb 0x8c5
#define MN_kandnb 0x8ce
#define MN_psignb (MN_vpsignb + 1)
#define MN_vpsignb 0x8d5
#define MN_jnb 0x8dd
#define MN_ccmpnb 0x8e1
#define MN_setnb 0x8e8
#define MN_ctestnb 0x8ee
#define MN_setzunb 0x8f6
#define MN_cmovnb (MN_fcmovnb + 1)
#define MN_fcmovnb (MN_cfcmovnb + 1)
#define MN_cfcmovnb 0x8fe
#define MN_ccmpb 0x907
#define MN_vpcmpb 0x90d
#define MN_vpcomeqb 0x914
#define MN_gf2p8affineqb (MN_vgf2p8affineqb + 1)
#define MN_vgf2p8affineqb 0x91d
#define MN_vpcomneqb 0x92c
#define MN_vpcmpneqb 0x936
#define MN_pcmpeqb (MN_vpcmpeqb + 1)
#define MN_vpcmpeqb 0x940
#define MN_vpmovusqb 0x949
#define MN_vpmovsqb 0x953
#define MN_vpmultishiftqb 0x95c
#define MN_gf2p8affineinvqb (MN_vgf2p8affineinvqb + 1)
#define MN_vgf2p8affineinvqb 0x96b
#define MN_vpmovqb 0x97d
#define MN_rex_rb 0x985
#define MN_korb 0x98c
#define MN_kxnorb 0x991
#define MN_kxorb 0x998
#define MN_pinsrb (MN_vpinsrb + 1)
#define MN_vpinsrb 0x99e
#define MN_kshiftrb 0x9a6
#define MN_pextrb (MN_vpextrb + 1)
#define MN_vpextrb 0x9af
#define MN_rex_wrb 0x9b7
#define MN_pabsb (MN_vpabsb + 1)
#define MN_vpabsb 0x9bf
#define MN_psubsb (MN_vpsubsb + 1)
#define MN_vpsubsb 0x9c6
#define MN_paddsb (MN_vpaddsb + 1)
#define MN_vpaddsb 0x9ce
#define MN_pminsb (MN_vpminsb + 1)
#define MN_vpminsb 0x9d6
#define MN_vmovrsb 0x9de
#define MN_vpcompressb 0x9e6
#define MN_psubusb (MN_vpsubusb + 1)
#define MN_vpsubusb 0x9f2
#define MN_paddusb (MN_vpaddusb + 1)
#define MN_vpaddusb 0x9fb
#define MN_pavgusb 0xa04
#define MN_movsb 0xa0c
#define MN_pmaxsb (MN_vpmaxsb + 1)
#define MN_vpmaxsb 0xa12
#define MN_setb 0xa1a
#define MN_vpcomgtb 0xa1f
#define MN_pcmpgtb (MN_vpcmpgtb + 1)
#define MN_vpcmpgtb 0xa28
#define MN_vpcomltb 0xa31
#define MN_vpcmpnltb 0xa3a
#define MN_vpcmpltb 0xa44
#define MN_vpopcntb 0xa4d
#define MN_knotb 0xa56
#define MN_vprotb 0xa5c
#define MN_vpbroadcastb 0xa63
#define MN_ctestb 0xa70
#define MN_ktestb 0xa77
#define MN_kortestb 0xa7e
#define MN_vpcomgeub 0xa87
#define MN_vpcomleub 0xa91
#define MN_vpcmpnleub 0xa9b
#define MN_vpcmpleub 0xaa6
#define MN_vpcomfalseub 0xab0
#define MN_vpcomtrueub 0xabd
#define MN_vpcomub 0xac9
#define MN_pminub (MN_vpminub + 1)
#define MN_vpminub 0xad1
#define MN_vpcmpub 0xad9
#define MN_vpcomequb 0xae1
#define MN_vpcomnequb 0xaeb
#define MN_vpcmpnequb 0xaf6
#define MN_vpcmpequb 0xb01
#define MN_sub (MN_fsub + 1)
#define MN_fsub (MN_pfsub + 1)
#define MN_pfsub 0xb0b
#define MN_fisub 0xb11
#define MN_vpcomgtub 0xb17
#define MN_vpcomltub 0xb21
#define MN_vpcmpnltub 0xb2b
#define MN_vpcmpltub 0xb36
#define MN_pmaxub (MN_vpmaxub + 1)
#define MN_vpmaxub 0xb40
#define MN_setzub 0xb48
#define MN_pblendvb (MN_vpblendvb + 1)
#define MN_vpblendvb 0xb4f
#define MN_cmovb (MN_fcmovb + 1)
#define MN_fcmovb (MN_cfcmovb + 1)
#define MN_cfcmovb 0xb59
#define MN_kmovb 0xb61
#define MN_rex_wb 0xb67
#define MN_clwb 0xb6e
#define MN_packsswb (MN_vpacksswb + 1)
#define MN_vpacksswb 0xb73
#define MN_packuswb (MN_vpackuswb + 1)
#define MN_vpackuswb 0xb7d
#define MN_vpmovuswb 0xb87
#define MN_vpmovswb 0xb91
#define MN_vpmovwb 0xb9a
#define MN_rex_xb 0xba2
#define MN_rex_rxb 0xba9
#define MN_rex_wrxb 0xbb1
#define MN_rex_wxb 0xbba
#define MN_movzb 0xbc2
#define MN_clac 0xbc8
#define MN_stac 0xbcd
#define MN_xcrypt_cbc 0xbd2
#define MN_xcryptcbc 0xbdd
#define MN_pfacc 0xbe7
#define MN_pfnacc 0xbed
#define MN_pfpnacc 0xbf4
#define MN_adc 0xbfc
#define MN_dec (MN_aesdec + 3)
#define MN_aesdec (MN_vaesdec + 1)
#define MN_vaesdec 0xc00
#define MN_getsec 0xc08
#define MN_xsavec 0xc0f
#define MN_blcic 0xc16
#define MN_blsic 0xc1c
#define MN_jc 0xc22
#define MN_t1mskc 0xc25
#define MN_clc 0xc2c
#define MN_cmc 0xc30
#define MN_aesimc (MN_vaesimc + 1)
#define MN_vaesimc 0xc34
#define MN_rdpmc 0xc3c
#define MN_aesenc (MN_vaesenc + 1)
#define MN_vaesenc 0xc42
#define MN_inc 0xc4a
#define MN_jnc 0xc4e
#define MN_ccmpnc 0xc52
#define MN_setnc 0xc59
#define MN_ctestnc 0xc5f
#define MN_vmfunc 0xc67
#define MN_setzunc 0xc6e
#define MN_cmovnc (MN_cfcmovnc + 2)
#define MN_cfcmovnc 0xc76
#define MN_tlbsync 0xc7f
#define MN_ccmpc 0xc87
#define MN_rdtsc 0xc8d
#define MN_btc 0xc93
#define MN_setc 0xc97
#define MN_stc (MN_ctestc + 3)
#define MN_ctestc 0xc9c
#define MN_setzuc 0xca3
#define MN_cmovc (MN_cfcmovc + 2)
#define MN_cfcmovc 0xcaa
#define MN_vpermi2d 0xcb2
#define MN_vpmovm2d 0xcbb
#define MN_vpermt2d 0xcc4
#define MN_vpbroadcastmw2d 0xccd
#define MN_aad 0xcdd
#define MN_vmread 0xce1
#define MN_rmpread 0xce8
#define MN_vpshad 0xcf0
#define MN_vmload 0xcf7
#define MN_psrad (MN_vpsrad + 1)
#define MN_vpsrad 0xcfe
#define MN_vphaddbd 0xd05
#define MN_vphaddubd 0xd0e
#define MN_phsubd (MN_vphsubd + 1)
#define MN_vphsubd 0xd18
#define MN_psubd (MN_vpsubd + 1)
#define MN_vpsubd 0xd20
#define MN_pmovsxbd (MN_vpmovsxbd + 1)
#define MN_vpmovsxbd 0xd27
#define MN_pmovzxbd (MN_vpmovzxbd + 1)
#define MN_vpmovzxbd 0xd31
#define MN_add (MN_aadd + 1)
#define MN_aadd 0xd3b
#define MN_fadd (MN_pfadd + 1)
#define MN_pfadd 0xd40
#define MN_fiadd 0xd46
#define MN_tileloadd 0xd4c
#define MN_xadd (MN_cmpnaxadd + 5)
#define MN_cmpnaxadd 0xd56
#define MN_cmpaxadd 0xd60
#define MN_cmpnbxadd 0xd69
#define MN_cmpbxadd 0xd73
#define MN_cmpncxadd 0xd7c
#define MN_cmpcxadd 0xd86
#define MN_cmpnaexadd 0xd8f
#define MN_cmpaexadd 0xd9a
#define MN_cmpnbexadd 0xda4
#define MN_cmpbexadd 0xdaf
#define MN_cmpngexadd 0xdb9
#define MN_cmpgexadd 0xdc4
#define MN_cmpnlexadd 0xdce
#define MN_cmplexadd 0xdd9
#define MN_cmpnexadd 0xde3
#define MN_cmpexadd 0xded
#define MN_cmppexadd 0xdf6
#define MN_cmpngxadd 0xe00
#define MN_cmpgxadd 0xe0a
#define MN_cmpnlxadd 0xe13
#define MN_cmplxadd 0xe1d
#define MN_cmpnoxadd 0xe26
#define MN_cmpoxadd 0xe30
#define MN_cmppoxadd 0xe39
#define MN_cmpnpxadd 0xe43
#define MN_cmppxadd 0xe4d
#define MN_cmpnsxadd 0xe56
#define MN_cmpsxadd 0xe60
#define MN_cmpnzxadd 0xe69
#define MN_cmpzxadd 0xe73
#define MN_phaddd (MN_vphaddd + 1)
#define MN_vphaddd 0xe7c
#define MN_kaddd 0xe84
#define MN_paddd (MN_vpaddd + 1)
#define MN_vpaddd 0xe8a
#define MN_vpshldd 0xe91
#define MN_kandd 0xe99
#define MN_vpandd 0xe9f
#define MN_vpexpandd 0xea6
#define MN_vpblendd 0xeb0
#define MN_vpgatherdd 0xeb9
#define MN_vpscatterdd 0xec4
#define MN_vpshrdd 0xed0
#define MN_vpmacsdd 0xed8
#define MN_vpmacssdd 0xee1
#define MN_rdseed 0xeeb
#define MN_vpcomged 0xef2
#define MN_vpcomled 0xefb
#define MN_vpcmpnled 0xf04
#define MN_vpcmpled 0xf0e
#define MN_tilestored 0xf17
#define MN_vpcomfalsed 0xf22
#define MN_ttransposed 0xf2e
#define MN_vpcomtrued 0xf3a
#define MN_pi2fd 0xf45
#define MN_pshufd (MN_vpshufd + 1)
#define MN_vpshufd 0xf4b
#define MN_vpternlogd 0xf53
#define MN_pf2id 0xf5e
#define MN_invpcid 0xf64
#define MN_rdpid 0xf6c
#define MN_invvpid 0xf72
#define MN_cpuid 0xf7a
#define MN_fbld 0xf80
#define MN_cld 0xf85
#define MN_fld 0xf89
#define MN_shld (MN_vpshld + 2)
#define MN_vpshld 0xf8d
#define MN_fild 0xf94
#define MN_pslld (MN_vpslld + 1)
#define MN_vpslld 0xf99
#define MN_pmulld (MN_vpmulld + 1)
#define MN_vpmulld 0xfa0
#define MN_vprold 0xfa8
#define MN_psrld (MN_vpsrld + 1)
#define MN_vpsrld 0xfaf
#define MN_vmptrld 0xfb6
#define MN_kshiftld 0xfbe
#define MN_enqcmd 0xfc7
#define MN_vpblendmd 0xfce
#define MN_vptestnmd 0xfd8
#define MN_vpcomd 0xfe2
#define MN_vpermd 0xfe9
#define MN_vptestmd 0xff0
#define MN_and (MN_aand + 1)
#define MN_aand 0xff9
#define MN_pand (MN_vpand + 1)
#define MN_vpand 0xffe
#define MN_rdrand 0x1004
#define MN_bnd 0x100b
#define MN_kandnd 0x100f
#define MN_vpandnd 0x1016
#define MN_xend 0x101e
#define MN_valignd 0x1023
#define MN_psignd (MN_vpsignd + 1)
#define MN_vpsignd 0x102b
#define MN_bound 0x1033
#define MN_slod 0x1039
#define MN_vfmaddsub231pd 0x103e
#define MN_vfmsub231pd 0x104d
#define MN_vfnmsub231pd 0x1059
#define MN_vfmsubadd231pd 0x1066
#define MN_vfmadd231pd 0x1075
#define MN_vfnmadd231pd 0x1081
#define MN_vfmaddsub132pd 0x108e
#define MN_vfmsub132pd 0x109d
#define MN_vfnmsub132pd 0x10a9
#define MN_vfmsubadd132pd 0x10b6
#define MN_vfmadd132pd 0x10c5
#define MN_vfnmadd132pd 0x10d1
#define MN_vcvtph2pd 0x10de
#define MN_vpermi2pd 0x10e8
#define MN_cvtpi2pd 0x10f2
#define MN_vpermil2pd 0x10fb
#define MN_vexp2pd 0x1106
#define MN_cvtdq2pd (MN_vcvtdq2pd + 1)
#define MN_vcvtdq2pd 0x110e
#define MN_vcvtudq2pd 0x1118
#define MN_vcvtqq2pd 0x1123
#define MN_vcvtuqq2pd 0x112d
#define MN_cvtps2pd (MN_vcvtps2pd + 1)
#define MN_vcvtps2pd 0x1138
#define MN_vpermt2pd 0x1142
#define MN_vfmaddsub213pd 0x114c
#define MN_vfmsub213pd 0x115b
#define MN_vfnmsub213pd 0x1167
#define MN_vfmsubadd213pd 0x1174
#define MN_vfmadd213pd 0x1183
#define MN_vfnmadd213pd 0x118f
#define MN_vrcp14pd 0x119c
#define MN_vrsqrt14pd 0x11a5
#define MN_vrcp28pd 0x11b0
#define MN_vrsqrt28pd 0x11b9
#define MN_movapd (MN_vmovapd + 1)
#define MN_vmovapd 0x11c4
#define MN_pswapd 0x11cc
#define MN_subpd (MN_addsubpd + 3)
#define MN_addsubpd (MN_vfmaddsubpd + 3)
#define MN_vfmaddsubpd 0x11d3
#define MN_vaddsubpd 0x11df
#define MN_hsubpd (MN_vhsubpd + 1)
#define MN_vhsubpd 0x11e9
#define MN_vfmsubpd 0x11f1
#define MN_vfnmsubpd 0x11fa
#define MN_vsubpd 0x1204
#define MN_vgatherpf0dpd 0x120b
#define MN_vscatterpf0dpd 0x1219
#define MN_vgatherpf1dpd 0x1228
#define MN_vscatterpf1dpd 0x1236
#define MN_addpd (MN_vfmsubaddpd + 6)
#define MN_vfmsubaddpd 0x1245
#define MN_haddpd (MN_vhaddpd + 1)
#define MN_vhaddpd 0x1251
#define MN_vfmaddpd 0x1259
#define MN_vfnmaddpd 0x1262
#define MN_vaddpd 0x126c
#define MN_andpd (MN_vexpandpd + 4)
#define MN_vexpandpd 0x1273
#define MN_vandpd 0x127d
#define MN_blendpd (MN_vblendpd + 1)
#define MN_vblendpd 0x1284
#define MN_roundpd (MN_vroundpd + 1)
#define MN_vroundpd 0x128d
#define MN_vgatherdpd 0x1296
#define MN_vscatterdpd 0x12a1
#define MN_cmpunordpd (MN_vcmpunordpd + 1)
#define MN_vcmpunordpd 0x12ad
#define MN_cmpordpd (MN_vcmpordpd + 1)
#define MN_vcmpordpd 0x12b9
#define MN_vreducepd 0x12c3
#define MN_vrangepd 0x12cd
#define MN_vcmpngepd 0x12d6
#define MN_vcmpgepd 0x12e0
#define MN_vrndscalepd 0x12e9
#define MN_cmpnlepd (MN_vcmpnlepd + 1)
#define MN_vcmpnlepd 0x12f5
#define MN_cmplepd (MN_vcmplepd + 1)
#define MN_vcmplepd 0x12ff
#define MN_vcmpfalsepd 0x1308
#define MN_vcmptruepd 0x1314
#define MN_vscalefpd 0x131f
#define MN_shufpd (MN_vshufpd + 1)
#define MN_vshufpd 0x1329
#define MN_unpckhpd (MN_vunpckhpd + 1)
#define MN_vunpckhpd 0x1331
#define MN_movhpd (MN_vmovhpd + 1)
#define MN_vmovhpd 0x133b
#define MN_movmskpd (MN_vmovmskpd + 1)
#define MN_vmovmskpd 0x1343
#define MN_vpermilpd 0x134d
#define MN_unpcklpd (MN_vunpcklpd + 1)
#define MN_vunpcklpd 0x1357
#define MN_mulpd (MN_vmulpd + 1)
#define MN_vmulpd 0x1361
#define MN_movlpd (MN_vmovlpd + 1)
#define MN_vmovlpd 0x1368
#define MN_vpcmpd 0x1370
#define MN_vblendmpd 0x1377
#define MN_vfixupimmpd 0x1381
#define MN_vpermpd 0x138d
#define MN_andnpd (MN_vandnpd + 1)
#define MN_vandnpd 0x1395
#define MN_minpd (MN_vminpd + 1)
#define MN_vminpd 0x139d
#define MN_dppd (MN_vdppd + 1)
#define MN_vdppd 0x13a4
#define MN_cmppd (MN_vcmppd + 1)
#define MN_vcmppd 0x13aa
#define MN_vgetexppd 0x13b1
#define MN_vgatherpf0qpd 0x13bb
#define MN_vscatterpf0qpd 0x13c9
#define MN_vgatherpf1qpd 0x13d8
#define MN_vscatterpf1qpd 0x13e6
#define MN_vcmpunord_qpd 0x13f5
#define MN_vcmpord_qpd 0x1403
#define MN_cmpneqpd (MN_vcmpneqpd + 1)
#define MN_vcmpneqpd 0x140f
#define MN_cmpeqpd (MN_vcmpeqpd + 1)
#define MN_vcmpeqpd 0x1419
#define MN_vcmpge_oqpd 0x1422
#define MN_vcmple_oqpd 0x142e
#define MN_vcmpfalse_oqpd 0x143a
#define MN_vcmpneq_oqpd 0x1449
#define MN_vcmpeq_oqpd 0x1456
#define MN_vcmpgt_oqpd 0x1462
#define MN_vcmplt_oqpd 0x146e
#define MN_vgatherqpd 0x147a
#define MN_vscatterqpd 0x1485
#define MN_vcmpnge_uqpd 0x1491
#define MN_vcmpnle_uqpd 0x149e
#define MN_vcmptrue_uqpd 0x14ab
#define MN_vcmpneq_uqpd 0x14b9
#define MN_vcmpeq_uqpd 0x14c6
#define MN_vcmpngt_uqpd 0x14d2
#define MN_vcmpnlt_uqpd 0x14df
#define MN_orpd (MN_vorpd + 1)
#define MN_vorpd 0x14ec
#define MN_xorpd (MN_vxorpd + 1)
#define MN_vxorpd 0x14f2
#define MN_vcmpunord_spd 0x14f9
#define MN_vcmpord_spd 0x1507
#define MN_vcmpge_ospd 0x1513
#define MN_vcmple_ospd 0x151f
#define MN_vcmpfalse_ospd 0x152b
#define MN_vcmpneq_ospd 0x153a
#define MN_vcmpeq_ospd 0x1547
#define MN_vcmpgt_ospd 0x1553
#define MN_vcmplt_ospd 0x155f
#define MN_vfpclasspd 0x156b
#define MN_incsspd 0x1576
#define MN_rdsspd 0x157e
#define MN_vcompresspd 0x1585
#define MN_vcmpnge_uspd 0x1591
#define MN_vcmpnle_uspd 0x159e
#define MN_vcmptrue_uspd 0x15ab
#define MN_vcmpneq_uspd 0x15b9
#define MN_vcmpeq_uspd 0x15c6
#define MN_vcmpngt_uspd 0x15d2
#define MN_vcmpnlt_uspd 0x15df
#define MN_vcmpngtpd 0x15ec
#define MN_vcmpgtpd 0x15f6
#define MN_cmpnltpd (MN_vcmpnltpd + 1)
#define MN_vcmpnltpd 0x15ff
#define MN_cmpltpd (MN_vcmpltpd + 1)
#define MN_vcmpltpd 0x1609
#define MN_vgetmantpd 0x1612
#define MN_movntpd (MN_vmovntpd + 1)
#define MN_vmovntpd 0x161d
#define MN_sqrtpd (MN_vsqrtpd + 1)
#define MN_vsqrtpd 0x1626
#define MN_vtestpd 0x162e
#define MN_movupd (MN_vmovupd + 1)
#define MN_vmovupd 0x1636
#define MN_blendvpd (MN_vblendvpd + 1)
#define MN_vblendvpd 0x163e
#define MN_divpd (MN_vdivpd + 1)
#define MN_vdivpd 0x1648
#define MN_vmaskmovpd 0x164f
#define MN_maxpd (MN_vminmaxpd + 4)
#define MN_vminmaxpd 0x165a
#define MN_vmaxpd 0x1664
#define MN_vfrczpd 0x166b
#define MN_vpcomeqd 0x1673
#define MN_vpcomneqd 0x167c
#define MN_vpcmpneqd 0x1686
#define MN_pcmpeqd (MN_vpcmpeqd + 1)
#define MN_vpcmpeqd 0x1690
#define MN_vpgatherqd 0x1699
#define MN_vpscatterqd 0x16a4
#define MN_vpmovusqd 0x16b0
#define MN_vpmovsqd 0x16ba
#define MN_vpmovqd 0x16c3
#define MN_shrd 0x16cb
#define MN_kord 0x16d0
#define MN_kxnord 0x16d5
#define MN_vpord 0x16dc
#define MN_vprord 0x16e2
#define MN_word (MN_aword + 1)
#define MN_aword 0x16e9
#define MN_dword (MN_adword + 1)
#define MN_adword 0x16ef
#define MN_kxord 0x16f6
#define MN_vpxord 0x16fc
#define MN_pinsrd (MN_vpinsrd + 1)
#define MN_vpinsrd 0x1703
#define MN_kshiftrd 0x170b
#define MN_pextrd (MN_vpextrd + 1)
#define MN_vpextrd 0x1714
#define MN_vfmsub231sd 0x171c
#define MN_vfnmsub231sd 0x1728
#define MN_vfmadd231sd 0x1735
#define MN_vfnmadd231sd 0x1741
#define MN_vfmsub132sd 0x174e
#define MN_vfnmsub132sd 0x175a
#define MN_vfmadd132sd 0x1767
#define MN_vfnmadd132sd 0x1773
#define MN_vcvtsh2sd 0x1780
#define MN_cvtsi2sd (MN_vcvtsi2sd + 1)
#define MN_vcvtsi2sd 0x178a
#define MN_vcvtusi2sd 0x1794
#define MN_cvtss2sd (MN_vcvtss2sd + 1)
#define MN_vcvtss2sd 0x179f
#define MN_vfmsub213sd 0x17a9
#define MN_vfnmsub213sd 0x17b5
#define MN_vfmadd213sd 0x17c2
#define MN_vfnmadd213sd 0x17ce
#define MN_vrcp14sd 0x17db
#define MN_vrsqrt14sd 0x17e4
#define MN_vrcp28sd 0x17ef
#define MN_vrsqrt28sd 0x17f8
#define MN_pabsd (MN_vpabsd + 1)
#define MN_vpabsd 0x1803
#define MN_subsd (MN_vfmsubsd + 3)
#define MN_vfmsubsd 0x180a
#define MN_vfnmsubsd 0x1813
#define MN_vsubsd 0x181d
#define MN_addsd (MN_vfmaddsd + 3)
#define MN_vfmaddsd 0x1824
#define MN_vfnmaddsd 0x182d
#define MN_vaddsd 0x1837
#define MN_roundsd (MN_vroundsd + 1)
#define MN_vroundsd 0x183e
#define MN_cmpunordsd (MN_vcmpunordsd + 1)
#define MN_vcmpunordsd 0x1847
#define MN_cmpordsd (MN_vcmpordsd + 1)
#define MN_vcmpordsd 0x1853
#define MN_vreducesd 0x185d
#define MN_vrangesd 0x1867
#define MN_vcmpngesd 0x1870
#define MN_vcmpgesd 0x187a
#define MN_vrndscalesd 0x1883
#define MN_cmpnlesd (MN_vcmpnlesd + 1)
#define MN_vcmpnlesd 0x188f
#define MN_cmplesd (MN_vcmplesd + 1)
#define MN_vcmplesd 0x1899
#define MN_vcmpfalsesd 0x18a2
#define MN_vcmptruesd 0x18ae
#define MN_vscalefsd 0x18b9
#define MN_comisd (MN_ucomisd + 1)
#define MN_ucomisd (MN_vucomisd + 1)
#define MN_vucomisd 0x18c3
#define MN_vcomisd 0x18cc
#define MN_mulsd (MN_vmulsd + 1)
#define MN_vmulsd 0x18d4
#define MN_vfixupimmsd 0x18db
#define MN_minsd (MN_pminsd + 1)
#define MN_pminsd (MN_vpminsd + 1)
#define MN_vpminsd 0x18e7
#define MN_vminsd 0x18ef
#define MN_cmpsd (MN_vcmpsd + 1)
#define MN_vcmpsd 0x18f6
#define MN_vgetexpsd 0x18fd
#define MN_vcmpunord_qsd 0x1907
#define MN_vcmpord_qsd 0x1915
#define MN_cmpneqsd (MN_vcmpneqsd + 1)
#define MN_vcmpneqsd 0x1921
#define MN_cmpeqsd (MN_vcmpeqsd + 1)
#define MN_vcmpeqsd 0x192b
#define MN_vcmpge_oqsd 0x1934
#define MN_vcmple_oqsd 0x1940
#define MN_vcmpfalse_oqsd 0x194c
#define MN_vcmpneq_oqsd 0x195b
#define MN_vcmpeq_oqsd 0x1968
#define MN_vcmpgt_oqsd 0x1974
#define MN_vcmplt_oqsd 0x1980
#define MN_vcmpnge_uqsd 0x198c
#define MN_vcmpnle_uqsd 0x1999
#define MN_vcmptrue_uqsd 0x19a6
#define MN_vcmpneq_uqsd 0x19b4
#define MN_vcmpeq_uqsd 0x19c1
#define MN_vcmpngt_uqsd 0x19cd
#define MN_vcmpnlt_uqsd 0x19da
#define MN_vmovrsd 0x19e7
#define MN_vcmpunord_ssd 0x19ef
#define MN_vcmpord_ssd 0x19fd
#define MN_vpdpbssd 0x1a09
#define MN_tdpbssd 0x1a12
#define MN_vpcompressd 0x1a1a
#define MN_vcmpge_ossd 0x1a26
#define MN_vcmple_ossd 0x1a32
#define MN_vcmpfalse_ossd 0x1a3e
#define MN_vcmpneq_ossd 0x1a4d
#define MN_vcmpeq_ossd 0x1a5a
#define MN_vcmpgt_ossd 0x1a66
#define MN_vcmplt_ossd 0x1a72
#define MN_wrssd 0x1a7e
#define MN_vfpclasssd 0x1a84
#define MN_vcmpnge_ussd 0x1a8f
#define MN_vcmpnle_ussd 0x1a9c
#define MN_vcmptrue_ussd 0x1aa9
#define MN_vcmpneq_ussd 0x1ab7
#define MN_vcmpeq_ussd 0x1ac4
#define MN_vcmpngt_ussd 0x1ad0
#define MN_vcmpnlt_ussd 0x1add
#define MN_wrussd 0x1aea
#define MN_vp4dpwssd 0x1af1
#define MN_vpdpwssd 0x1afb
#define MN_vcmpngtsd 0x1b04
#define MN_vcmpgtsd 0x1b0e
#define MN_cmpnltsd (MN_vcmpnltsd + 1)
#define MN_vcmpnltsd 0x1b17
#define MN_cmpltsd (MN_vcmpltsd + 1)
#define MN_vcmpltsd 0x1b21
#define MN_vgetmantsd 0x1b2a
#define MN_movntsd 0x1b35
#define MN_sqrtsd (MN_vsqrtsd + 1)
#define MN_vsqrtsd 0x1b3d
#define MN_vbroadcastsd 0x1b45
#define MN_vpdpbusd 0x1b52
#define MN_tdpbusd 0x1b5b
#define MN_vpdpwusd 0x1b63
#define MN_divsd (MN_vdivsd + 1)
#define MN_vdivsd 0x1b6c
#define MN_movsd (MN_vmovsd + 1)
#define MN_vmovsd 0x1b73
#define MN_maxsd (MN_vminmaxsd + 4)
#define MN_vminmaxsd 0x1b7a
#define MN_pmaxsd (MN_vpmaxsd + 1)
#define MN_vpmaxsd 0x1b84
#define MN_vmaxsd 0x1b8c
#define MN_vucomxsd 0x1b93
#define MN_vcomxsd 0x1b9c
#define MN_vfrczsd 0x1ba4
#define MN_vp2intersectd 0x1bac
#define MN_vpconflictd 0x1bba
#define MN_vpcomgtd 0x1bc6
#define MN_pcmpgtd (MN_vpcmpgtd + 1)
#define MN_vpcmpgtd 0x1bcf
#define MN_cltd 0x1bd8
#define MN_vpcomltd 0x1bdd
#define MN_vpcmpnltd 0x1be6
#define MN_vpcmpltd 0x1bf0
#define MN_vpopcntd 0x1bf9
#define MN_vplzcntd 0x1c02
#define MN_knotd 0x1c0b
#define MN_vprotd 0x1c11
#define MN_std (MN_vpbroadcastd + 9)
#define MN_vpbroadcastd 0x1c18
#define MN_ktestd 0x1c25
#define MN_kortestd 0x1c2c
#define MN_cwtd 0x1c35
#define MN_vpcomgeud 0x1c3a
#define MN_vpcomleud 0x1c44
#define MN_vpcmpnleud 0x1c4e
#define MN_vpcmpleud 0x1c59
#define MN_vpcomfalseud 0x1c63
#define MN_vpcomtrueud 0x1c70
#define MN_vpcomud 0x1c7c
#define MN_pminud (MN_vpminud + 1)
#define MN_vpminud 0x1c84
#define MN_vpcmpud 0x1c8c
#define MN_vpcomequd 0x1c94
#define MN_vpcomnequd 0x1c9e
#define MN_vpcmpnequd 0x1ca9
#define MN_vpcmpequd 0x1cb4
#define MN_vpdpbsud 0x1cbe
#define MN_tdpbsud 0x1cc7
#define MN_vpdpwsud 0x1ccf
#define MN_vpcomgtud 0x1cd8
#define MN_vpcomltud 0x1ce2
#define MN_vpcmpnltud 0x1cec
#define MN_vpcmpltud 0x1cf7
#define MN_vpdpbuud 0x1d01
#define MN_tdpbuud 0x1d0a
#define MN_vpdpwuud 0x1d12
#define MN_pmaxud (MN_vpmaxud + 1)
#define MN_vpmaxud 0x1d1b
#define MN_vpsravd 0x1d23
#define MN_vpshldvd 0x1d2b
#define MN_vpshrdvd 0x1d34
#define MN_vpsllvd 0x1d3d
#define MN_vprolvd 0x1d45
#define MN_vpsrlvd 0x1d4d
#define MN_invd (MN_wbinvd + 2)
#define MN_wbinvd 0x1d55
#define MN_wbnoinvd 0x1d5c
#define MN_movd (MN_kmovd + 1)
#define MN_kmovd (MN_vpmaskmovd + 5)
#define MN_vpmaskmovd 0x1d65
#define MN_vmovd 0x1d70
#define MN_vprorvd 0x1d76
#define MN_vphsubwd 0x1d7e
#define MN_cwd 0x1d87
#define MN_vphaddwd 0x1d8b
#define MN_pmaddwd (MN_vpmaddwd + 1)
#define MN_vpmaddwd 0x1d94
#define MN_punpckhwd (MN_vpunpckhwd + 1)
#define MN_vpunpckhwd 0x1d9d
#define MN_kunpckwd 0x1da8
#define MN_punpcklwd (MN_vpunpcklwd + 1)
#define MN_vpunpcklwd 0x1db1
#define MN_vpmacswd 0x1dbc
#define MN_vpmadcswd 0x1dc5
#define MN_vpmacsswd 0x1dcf
#define MN_vpmadcsswd 0x1dd9
#define MN_vphadduwd 0x1de4
#define MN_pmovsxwd (MN_vpmovsxwd + 1)
#define MN_vpmovsxwd 0x1dee
#define MN_pmovzxwd (MN_vpmovzxwd + 1)
#define MN_vpmovzxwd 0x1df8
#define MN_movsxd 0x1e02
#define MN_fldl2e 0x1e09
#define MN_jae 0x1e10
#define MN_jnae 0x1e14
#define MN_ccmpnae 0x1e19
#define MN_setnae 0x1e21
#define MN_ctestnae 0x1e28
#define MN_setzunae 0x1e31
#define MN_cmovnae (MN_fcmovnae + 1)
#define MN_fcmovnae (MN_cfcmovnae + 1)
#define MN_cfcmovnae 0x1e3a
#define MN_ccmpae 0x1e44
#define MN_setae 0x1e4b
#define MN_ctestae 0x1e51
#define MN_setzuae 0x1e59
#define MN_cmovae (MN_fcmovae + 1)
#define MN_fcmovae (MN_cfcmovae + 1)
#define MN_cfcmovae 0x1e61
#define MN_jbe 0x1e6a
#define MN_jnbe 0x1e6e
#define MN_ccmpnbe 0x1e73
#define MN_setnbe 0x1e7b
#define MN_ctestnbe 0x1e82
#define MN_setzunbe 0x1e8b
#define MN_cmovnbe (MN_fcmovnbe + 1)
#define MN_fcmovnbe (MN_cfcmovnbe + 1)
#define MN_cfcmovnbe 0x1e94
#define MN_ccmpbe 0x1e9e
#define MN_setbe 0x1ea5
#define MN_ctestbe 0x1eab
#define MN_setzube 0x1eb3
#define MN_movbe (MN_cmovbe + 1)
#define MN_cmovbe (MN_fcmovbe + 1)
#define MN_fcmovbe (MN_cfcmovbe + 1)
#define MN_cfcmovbe 0x1ebb
#define MN_lfence 0x1ec4
#define MN_mfence 0x1ecb
#define MN_sfence 0x1ed2
#define MN_cwde 0x1ed9
#define MN_ffree 0x1ede
#define MN_jge 0x1ee4
#define MN_jnge 0x1ee8
#define MN_ccmpnge 0x1eed
#define MN_setnge 0x1ef5
#define MN_ctestnge 0x1efc
#define MN_setzunge 0x1f05
#define MN_cmovnge (MN_cfcmovnge + 2)
#define MN_cfcmovnge 0x1f0e
#define MN_ccmpge 0x1f18
#define MN_pfcmpge 0x1f1f
#define MN_setge 0x1f27
#define MN_ctestge 0x1f2d
#define MN_setzuge 0x1f35
#define MN_cmovge (MN_cfcmovge + 2)
#define MN_cfcmovge 0x1f3d
#define MN_je 0x1f46
#define MN_fscale 0x1f49
#define MN_jle 0x1f50
#define MN_jnle 0x1f54
#define MN_ccmpnle 0x1f59
#define MN_setnle 0x1f61
#define MN_ctestnle 0x1f68
#define MN_setzunle 0x1f71
#define MN_cmovnle (MN_cfcmovnle + 2)
#define MN_cfcmovnle 0x1f7a
#define MN_ccmple 0x1f84
#define MN_setle 0x1f8b
#define MN_ctestle 0x1f91
#define MN_setzule 0x1f99
#define MN_cmovle (MN_cfcmovle + 2)
#define MN_cfcmovle 0x1fa1
#define MN_vmresume 0x1faa
#define MN_jne 0x1fb3
#define MN_repne 0x1fb7
#define MN_ccmpne 0x1fbd
#define MN_loopne 0x1fc4
#define MN_setne 0x1fcb
#define MN_ctestne 0x1fd1
#define MN_setzune 0x1fd9
#define MN_cmovne (MN_fcmovne + 1)
#define MN_fcmovne (MN_cfcmovne + 1)
#define MN_cfcmovne 0x1fe1
#define MN_repe 0x1fea
#define MN_jpe 0x1fef
#define MN_ccmpe 0x1ff3
#define MN_loope 0x1ff9
#define MN_setpe 0x1fff
#define MN_setzupe 0x2005
#define MN_cmovpe (MN_cfcmovpe + 2)
#define MN_cfcmovpe 0x200d
#define MN_cdqe 0x2016
#define MN_xacquire 0x201b
#define MN_xstore 0x2024
#define MN_rdfsbase 0x202b
#define MN_wrfsbase 0x2034
#define MN_rdgsbase 0x203d
#define MN_wrgsbase 0x2046
#define MN_tilerelease 0x204f
#define MN_xrelease 0x205b
#define MN_pause (MN_tpause + 1)
#define MN_tpause 0x2064
#define MN_pvalidate 0x206b
#define MN_rmpupdate 0x2075
#define MN_sete 0x207f
#define MN_vmwrite 0x2084
#define MN_ptwrite 0x208c
#define MN_cldemote 0x2094
#define MN_cteste 0x209d
#define MN_sha1nexte 0x20a4
#define MN_setzue 0x20ae
#define MN_leave 0x20b5
#define MN_fsave 0x20bb
#define MN_vmsave 0x20c1
#define MN_fnsave 0x20c8
#define MN_xsave (MN_fxsave + 1)
#define MN_fxsave 0x20cf
#define MN_cmove (MN_fcmove + 1)
#define MN_fcmove (MN_cfcmove + 1)
#define MN_cfcmove 0x20d6
#define MN_serialize 0x20de
#define MN_vmxoff 0x20e8
#define MN_lahf 0x20ef
#define MN_sahf 0x20f4
#define MN_pushf 0x20f9
#define MN_ccmpf 0x20ff
#define MN_popf 0x2105
#define MN_bsf 0x210a
#define MN_retf 0x210e
#define MN_ctestf 0x2113
#define MN_neg 0x211a
#define MN_ldtilecfg 0x211e
#define MN_sttilecfg 0x2128
#define MN_xchg (MN_cmpxchg + 3)
#define MN_cmpxchg 0x2132
#define MN_pconfig 0x213a
#define MN_jg 0x2142
#define MN_jng 0x2145
#define MN_ccmpng 0x2149
#define MN_xstore_rng 0x2150
#define MN_xstorerng 0x215b
#define MN_setng 0x2165
#define MN_ctestng 0x216b
#define MN_setzung 0x2173
#define MN_cmovng (MN_cfcmovng + 2)
#define MN_cfcmovng 0x217b
#define MN_invlpg 0x2184
#define MN_ccmpg 0x218b
#define MN_setg 0x2191
#define MN_ctestg 0x2196
#define MN_setzug 0x219d
#define MN_cmovg (MN_cfcmovg + 2)
#define MN_cfcmovg 0x21a4
#define MN_tcvtrowps2bf16h 0x21ac
#define MN_vmlaunch 0x21bc
#define MN_prefetch 0x21c5
#define MN_fxch 0x21ce
#define MN_tcvtrowps2phh 0x21d3
#define MN_vfmaddsub231ph 0x21e1
#define MN_vfmsub231ph 0x21f0
#define MN_vfnmsub231ph 0x21fc
#define MN_vfmsubadd231ph 0x2209
#define MN_vfmadd231ph 0x2218
#define MN_vfnmadd231ph 0x2224
#define MN_vfmaddsub132ph 0x2231
#define MN_vfmsub132ph 0x2240
#define MN_vfnmsub132ph 0x224c
#define MN_vfmsubadd132ph 0x2259
#define MN_vfmadd132ph 0x2268
#define MN_vfnmadd132ph 0x2274
#define MN_vcvthf82ph 0x2281
#define MN_vcvtpd2ph 0x228c
#define MN_vcvtdq2ph 0x2296
#define MN_vcvtudq2ph 0x22a0
#define MN_vcvtqq2ph 0x22ab
#define MN_vcvtuqq2ph 0x22b5
#define MN_vcvtps2ph 0x22c0
#define MN_vcvtw2ph 0x22ca
#define MN_vcvtuw2ph 0x22d3
#define MN_vfmaddsub213ph 0x22dd
#define MN_vfmsub213ph 0x22ec
#define MN_vfnmsub213ph 0x22f8
#define MN_vfmsubadd213ph 0x2305
#define MN_vfmadd213ph 0x2314
#define MN_vfnmadd213ph 0x2320
#define MN_vsubph 0x232d
#define MN_vfcmaddcph 0x2334
#define MN_vfmaddcph 0x233f
#define MN_vfcmulcph 0x2349
#define MN_vfmulcph 0x2353
#define MN_vaddph 0x235c
#define MN_vcmpunordph 0x2363
#define MN_vcmpordph 0x236f
#define MN_vreduceph 0x2379
#define MN_vcmpngeph 0x2383
#define MN_vcmpgeph 0x238d
#define MN_vrndscaleph 0x2396
#define MN_vcmpnleph 0x23a2
#define MN_vcmpleph 0x23ac
#define MN_vcmpfalseph 0x23b5
#define MN_vcmptrueph 0x23c1
#define MN_vscalefph 0x23cc
#define MN_vmulph 0x23d6
#define MN_vminph 0x23dd
#define MN_vrcpph 0x23e4
#define MN_vcmpph 0x23eb
#define MN_vgetexpph 0x23f2
#define MN_vcmpunord_qph 0x23fc
#define MN_vcmpord_qph 0x240a
#define MN_vcmpneqph 0x2416
#define MN_vcmpeqph 0x2420
#define MN_vcmpge_oqph 0x2429
#define MN_vcmple_oqph 0x2435
#define MN_vcmpfalse_oqph 0x2441
#define MN_vcmpneq_oqph 0x2450
#define MN_vcmpeq_oqph 0x245d
#define MN_vcmpgt_oqph 0x2469
#define MN_vcmplt_oqph 0x2475
#define MN_vcmpnge_uqph 0x2481
#define MN_vcmpnle_uqph 0x248e
#define MN_vcmptrue_uqph 0x249b
#define MN_vcmpneq_uqph 0x24a9
#define MN_vcmpeq_uqph 0x24b6
#define MN_vcmpngt_uqph 0x24c2
#define MN_vcmpnlt_uqph 0x24cf
#define MN_vcmpunord_sph 0x24dc
#define MN_vcmpord_sph 0x24ea
#define MN_vcmpge_osph 0x24f6
#define MN_vcmple_osph 0x2502
#define MN_vcmpfalse_osph 0x250e
#define MN_vcmpneq_osph 0x251d
#define MN_vcmpeq_osph 0x252a
#define MN_vcmpgt_osph 0x2536
#define MN_vcmplt_osph 0x2542
#define MN_vfpclassph 0x254e
#define MN_vcmpnge_usph 0x2559
#define MN_vcmpnle_usph 0x2566
#define MN_vcmptrue_usph 0x2573
#define MN_vcmpneq_usph 0x2581
#define MN_vcmpeq_usph 0x258e
#define MN_vcmpngt_usph 0x259a
#define MN_vcmpnlt_usph 0x25a7
#define MN_vcmpngtph 0x25b4
#define MN_vcmpgtph 0x25be
#define MN_vcmpnltph 0x25c7
#define MN_vcmpltph 0x25d1
#define MN_vgetmantph 0x25da
#define MN_vrsqrtph 0x25e5
#define MN_vsqrtph 0x25ee
#define MN_vdivph 0x25f6
#define MN_vminmaxph 0x25fd
#define MN_vmaxph 0x2607
#define MN_vpmacsdqh 0x260e
#define MN_vpmacssdqh 0x2618
#define MN_vfmsub231sh 0x2623
#define MN_vfnmsub231sh 0x262f
#define MN_vfmadd231sh 0x263c
#define MN_vfnmadd231sh 0x2648
#define MN_vfmsub132sh 0x2655
#define MN_vfnmsub132sh 0x2661
#define MN_vfmadd132sh 0x266e
#define MN_vfnmadd132sh 0x267a
#define MN_vcvtsd2sh 0x2687
#define MN_vcvtsi2sh 0x2691
#define MN_vcvtusi2sh 0x269b
#define MN_vcvtss2sh 0x26a6
#define MN_vfmsub213sh 0x26b0
#define MN_vfnmsub213sh 0x26bc
#define MN_vfmadd213sh 0x26c9
#define MN_vfnmadd213sh 0x26d5
#define MN_psmash 0x26e2
#define MN_vsubsh 0x26e9
#define MN_vfcmaddcsh 0x26f0
#define MN_vfmaddcsh 0x26fb
#define MN_vfcmulcsh 0x2705
#define MN_vfmulcsh 0x270f
#define MN_vaddsh 0x2718
#define MN_vcmpunordsh 0x271f
#define MN_vcmpordsh 0x272b
#define MN_vreducesh 0x2735
#define MN_vcmpngesh 0x273f
#define MN_vcmpgesh 0x2749
#define MN_vrndscalesh 0x2752
#define MN_vcmpnlesh 0x275e
#define MN_vcmplesh 0x2768
#define MN_vcmpfalsesh 0x2771
#define MN_vcmptruesh 0x277d
#define MN_vscalefsh 0x2788
#define MN_vucomish 0x2792
#define MN_vcomish 0x279b
#define MN_vmulsh 0x27a3
#define MN_vminsh 0x27aa
#define MN_vrcpsh 0x27b1
#define MN_vcmpsh 0x27b8
#define MN_vgetexpsh 0x27bf
#define MN_vcmpunord_qsh 0x27c9
#define MN_vcmpord_qsh 0x27d7
#define MN_vcmpneqsh 0x27e3
#define MN_vcmpeqsh 0x27ed
#define MN_vcmpge_oqsh 0x27f6
#define MN_vcmple_oqsh 0x2802
#define MN_vcmpfalse_oqsh 0x280e
#define MN_vcmpneq_oqsh 0x281d
#define MN_vcmpeq_oqsh 0x282a
#define MN_vcmpgt_oqsh 0x2836
#define MN_vcmplt_oqsh 0x2842
#define MN_vcmpnge_uqsh 0x284e
#define MN_vcmpnle_uqsh 0x285b
#define MN_vcmptrue_uqsh 0x2868
#define MN_vcmpneq_uqsh 0x2876
#define MN_vcmpeq_uqsh 0x2883
#define MN_vcmpngt_uqsh 0x288f
#define MN_vcmpnlt_uqsh 0x289c
#define MN_vcmpunord_ssh 0x28a9
#define MN_vcmpord_ssh 0x28b7
#define MN_vcmpge_ossh 0x28c3
#define MN_vcmple_ossh 0x28cf
#define MN_vcmpfalse_ossh 0x28db
#define MN_vcmpneq_ossh 0x28ea
#define MN_vcmpeq_ossh 0x28f7
#define MN_vcmpgt_ossh 0x2903
#define MN_vcmplt_ossh 0x290f
#define MN_vfpclasssh 0x291b
#define MN_vcmpnge_ussh 0x2926
#define MN_vcmpnle_ussh 0x2933
#define MN_vcmptrue_ussh 0x2940
#define MN_vcmpneq_ussh 0x294e
#define MN_vcmpeq_ussh 0x295b
#define MN_vcmpngt_ussh 0x2967
#define MN_vcmpnlt_ussh 0x2974
#define MN_vcmpngtsh 0x2981
#define MN_vcmpgtsh 0x298b
#define MN_vcmpnltsh 0x2994
#define MN_vcmpltsh 0x299e
#define MN_vgetmantsh 0x29a7
#define MN_vrsqrtsh 0x29b2
#define MN_vsqrtsh 0x29bb
#define MN_clflush 0x29c3
#define MN_push 0x29cb
#define MN_vdivsh 0x29d0
#define MN_vmovsh 0x29d7
#define MN_vminmaxsh 0x29de
#define MN_vmaxsh 0x29e8
#define MN_vucomxsh 0x29ef
#define MN_vcomxsh 0x29f8
#define MN_blci 0x2a00
#define MN_clgi 0x2a05
#define MN_stgi 0x2a0a
#define MN_bzhi 0x2a0f
#define MN_cli 0x2a14
#define MN_fcomi 0x2a18
#define MN_fucomi 0x2a1e
#define MN_feni 0x2a25
#define MN_fneni 0x2a2a
#define MN_cvttpd2pi 0x2a30
#define MN_cvtpd2pi 0x2a3a
#define MN_cvttps2pi 0x2a43
#define MN_cvtps2pi 0x2a4d
#define MN_fldpi 0x2a56
#define MN_senduipi 0x2a5c
#define MN_fcompi 0x2a65
#define MN_fucompi 0x2a6c
#define MN_movdiri 0x2a74
#define MN_pcmpestri (MN_vpcmpestri + 1)
#define MN_vpcmpestri 0x2a7c
#define MN_pcmpistri (MN_vpcmpistri + 1)
#define MN_vpcmpistri 0x2a87
#define MN_cvttsd2si (MN_vcvttsd2si + 1)
#define MN_vcvttsd2si 0x2a92
#define MN_cvtsd2si (MN_vcvtsd2si + 1)
#define MN_vcvtsd2si 0x2a9d
#define MN_vcvttsh2si 0x2aa7
#define MN_vcvtsh2si 0x2ab2
#define MN_cvttss2si (MN_vcvttss2si + 1)
#define MN_vcvttss2si 0x2abc
#define MN_cvtss2si (MN_vcvtss2si + 1)
#define MN_vcvtss2si 0x2ac7
#define MN_fdisi 0x2ad1
#define MN_fndisi 0x2ad7
#define MN_blsi 0x2ade
#define MN_vcvttsd2usi 0x2ae3
#define MN_vcvtsd2usi 0x2aef
#define MN_vcvttsh2usi 0x2afa
#define MN_vcvtsh2usi 0x2b06
#define MN_vcvttss2usi 0x2b11
#define MN_vcvtss2usi 0x2b1d
#define MN_movnti 0x2b28
#define MN_sti 0x2b2f
#define MN_clui 0x2b33
#define MN_stui (MN_testui + 2)
#define MN_testui 0x2b38
#define MN_notrack 0x2b3f
#define MN_lock 0x2b47
#define MN_bndmk 0x2b4c
#define MN_xresldtrk 0x2b52
#define MN_xsusldtrk 0x2b5c
#define MN_blcmsk 0x2b66
#define MN_blsmsk 0x2b6d
#define MN_tzmsk 0x2b74
#define MN_tcvtrowps2bf16l 0x2b7a
#define MN_sal 0x2b8a
#define MN_lwpval 0x2b8e
#define MN_bndcl 0x2b95
#define MN_rcl 0x2b9b
#define MN_tcvtrowps2phl 0x2b9f
#define MN_shl 0x2bad
#define MN_jl 0x2bb1
#define MN_aesdec256kl 0x2bb4
#define MN_aesenc256kl 0x2bc0
#define MN_aesdecwide256kl 0x2bcc
#define MN_aesencwide256kl 0x2bdc
#define MN_aesdec128kl 0x2bec
#define MN_aesenc128kl 0x2bf8
#define MN_aesdecwide128kl 0x2c04
#define MN_aesencwide128kl 0x2c14
#define MN_call (MN_tdcall + 2)
#define MN_tdcall 0x2c24
#define MN_lcall 0x2c2b
#define MN_seamcall 0x2c31
#define MN_vmmcall 0x2c3a
#define MN_vmcall 0x2c42
#define MN_syscall 0x2c49
#define MN_vzeroall 0x2c51
#define MN_fildll 0x2c5a
#define MN_blcfill 0x2c61
#define MN_blsfill 0x2c69
#define MN_fistpll 0x2c71
#define MN_fisttpll 0x2c79
#define MN_jnl 0x2c82
#define MN_ccmpnl 0x2c86
#define MN_setnl 0x2c8d
#define MN_ctestnl 0x2c93
#define MN_setzunl 0x2c9b
#define MN_cmovnl (MN_cfcmovnl + 2)
#define MN_cfcmovnl 0x2ca3
#define MN_rol 0x2cac
#define MN_ccmpl 0x2cb0
#define MN_arpl 0x2cb6
#define MN_vpmacsdql 0x2cbb
#define MN_vpmacssdql 0x2cc5
#define MN_lsl 0x2cd0
#define MN_movsl 0x2cd4
#define MN_setl 0x2cda
#define MN_ctestl 0x2cdf
#define MN_cwtl 0x2ce6
#define MN_mul (MN_fmul + 1)
#define MN_fmul (MN_pfmul + 1)
#define MN_pfmul 0x2ceb
#define MN_imul (MN_fimul + 1)
#define MN_fimul 0x2cf1
#define MN_montmul 0x2cf7
#define MN_setzul 0x2cff
#define MN_cmovl (MN_cfcmovl + 2)
#define MN_cfcmovl 0x2d06
#define MN_vpmovb2m 0x2d0e
#define MN_vpmovd2m 0x2d17
#define MN_vpmovq2m 0x2d20
#define MN_vpmovw2m 0x2d29
#define MN_aam 0x2d32
#define MN_fxam 0x2d36
#define MN_fprem 0x2d3b
#define MN_fcom 0x2d41
#define MN_ficom 0x2d46
#define MN_fucom 0x2d4c
#define MN_fsetpm 0x2d52
#define MN_fnsetpm 0x2d59
#define MN_frstpm 0x2d61
#define MN_vpperm 0x2d68
#define MN_pcmpestrm (MN_vpcmpestrm + 1)
#define MN_vpcmpestrm 0x2d6f
#define MN_pcmpistrm (MN_vpcmpistrm + 1)
#define MN_vpcmpistrm 0x2d7a
#define MN_rsm 0x2d85
#define MN_fpatan 0x2d89
#define MN_fptan 0x2d90
#define MN_bndcn 0x2d96
#define MN_andn (MN_pandn + 1)
#define MN_pandn (MN_vpandn + 1)
#define MN_vpandn 0x2d9c
#define MN_in (MN_xbegin + 4)
#define MN_xbegin 0x2da3
#define MN_pfmin 0x2daa
#define MN_fsin 0x2db0
#define MN_vmxon 0x2db5
#define MN_vmrun 0x2dbb
#define MN_jo 0x2dc1
#define MN_jno 0x2dc4
#define MN_ccmpno 0x2dc8
#define MN_setno 0x2dcf
#define MN_ctestno 0x2dd5
#define MN_setzuno 0x2ddd
#define MN_cmovno (MN_cfcmovno + 2)
#define MN_cfcmovno 0x2de5
#define MN_jpo 0x2dee
#define MN_ccmpo 0x2df2
#define MN_setpo 0x2df8
#define MN_setzupo 0x2dfe
#define MN_cmovpo (MN_cfcmovpo + 2)
#define MN_cfcmovpo 0x2e06
#define MN_cqo 0x2e0f
#define MN_tilezero 0x2e13
#define MN_clzero 0x2e1c
#define MN_seto 0x2e23
#define MN_into 0x2e28
#define MN_cqto 0x2e2d
#define MN_ctesto 0x2e32
#define MN_ssto 0x2e39
#define MN_setzuo 0x2e3e
#define MN_cmovo (MN_cfcmovo + 2)
#define MN_cfcmovo 0x2e45
#define MN_push2p 0x2e4d
#define MN_pop2p 0x2e54
#define MN_bswap 0x2e5a
#define MN_fsubp 0x2e60
#define MN_pfrcp 0x2e66
#define MN_rdtscp 0x2e6c
#define MN_faddp 0x2e73
#define MN_pdep 0x2e79
#define MN_ffreep 0x2e7e
#define MN_rep 0x2e85
#define MN_pushp 0x2e89
#define MN_fcomip 0x2e8f
#define MN_fucomip 0x2e96
#define MN_jp 0x2e9e
#define MN_fmulp 0x2ea1
#define MN_cmp (MN_scmp + 1)
#define MN_scmp 0x2ea7
#define MN_jmp (MN_ljmp + 1)
#define MN_ljmp 0x2eac
#define MN_fcomp 0x2eb1
#define MN_ficomp 0x2eb7
#define MN_fucomp 0x2ebe
#define MN_jnp 0x2ec5
#define MN_setnp 0x2ec9
#define MN_setzunp 0x2ecf
#define MN_cmovnp (MN_cfcmovnp + 2)
#define MN_cfcmovnp 0x2ed7
#define MN_nop (MN_fnop + 1)
#define MN_fnop 0x2ee0
#define MN_loop 0x2ee5
#define MN_pop 0x2eea
#define MN_fcompp 0x2eee
#define MN_fucompp 0x2ef5
#define MN_popp 0x2efd
#define MN_fsubrp 0x2f02
#define MN_fdivrp 0x2f09
#define MN_rstorssp 0x2f10
#define MN_saveprevssp 0x2f19
#define MN_setp 0x2f25
#define MN_fbstp 0x2f2a
#define MN_fdecstp 0x2f30
#define MN_fincstp 0x2f38
#define MN_fstp 0x2f40
#define MN_fistp 0x2f45
#define MN_fisttp 0x2f4b
#define MN_movddup (MN_vmovddup + 1)
#define MN_vmovddup 0x2f52
#define MN_movshdup (MN_vmovshdup + 1)
#define MN_vmovshdup 0x2f5b
#define MN_movsldup (MN_vmovsldup + 1)
#define MN_vmovsldup 0x2f65
#define MN_setzup 0x2f6f
#define MN_fdivp 0x2f76
#define MN_cmovp (MN_cfcmovp + 2)
#define MN_cfcmovp 0x2f7c
#define MN_xmodexp 0x2f84
#define MN_vpbroadcastmb2q 0x2f8c
#define MN_vpermi2q 0x2f9c
#define MN_vpmovm2q 0x2fa5
#define MN_movdq2q 0x2fae
#define MN_vpermt2q 0x2fb6
#define MN_vpshaq 0x2fbf
#define MN_vpsraq 0x2fc6
#define MN_vphaddbq 0x2fcd
#define MN_vphaddubq 0x2fd6
#define MN_psubq (MN_vpsubq + 1)
#define MN_vpsubq 0x2fe0
#define MN_pmovsxbq (MN_vpmovsxbq + 1)
#define MN_vpmovsxbq 0x2fe7
#define MN_pmovzxbq (MN_vpmovzxbq + 1)
#define MN_vpmovzxbq 0x2ff1
#define MN_cvttpd2dq (MN_vcvttpd2dq + 1)
#define MN_vcvttpd2dq 0x2ffb
#define MN_cvtpd2dq (MN_vcvtpd2dq + 1)
#define MN_vcvtpd2dq 0x3006
#define MN_vcvttph2dq 0x3010
#define MN_vcvtph2dq 0x301b
#define MN_movq2dq 0x3025
#define MN_cvttps2dq (MN_vcvttps2dq + 1)
#define MN_vcvttps2dq 0x302d
#define MN_cvtps2dq (MN_vcvtps2dq + 1)
#define MN_vcvtps2dq 0x3038
#define MN_vphsubdq 0x3042
#define MN_cdq 0x304b
#define MN_kaddq 0x304f
#define MN_paddq (MN_vpaddq + 1)
#define MN_vpaddq 0x3055
#define MN_vphadddq 0x305c
#define MN_punpckhdq (MN_vpunpckhdq + 1)
#define MN_vpunpckhdq 0x3065
#define MN_kunpckdq 0x3070
#define MN_vpshldq 0x3079
#define MN_punpckldq (MN_vpunpckldq + 1)
#define MN_vpunpckldq 0x3081
#define MN_pslldq (MN_vpslldq + 1)
#define MN_vpslldq 0x308c
#define MN_psrldq (MN_vpsrldq + 1)
#define MN_vpsrldq 0x3094
#define MN_pmuldq (MN_vpmuldq + 1)
#define MN_vpmuldq 0x309c
#define MN_kandq 0x30a4
#define MN_vpandq 0x30aa
#define MN_vpexpandq 0x30b1
#define MN_punpckhqdq (MN_vpunpckhqdq + 1)
#define MN_vpunpckhqdq 0x30bb
#define MN_pclmulhqhqdq (MN_vpclmulhqhqdq + 1)
#define MN_vpclmulhqhqdq 0x30c7
#define MN_pclmullqhqdq (MN_vpclmullqhqdq + 1)
#define MN_vpclmullqhqdq 0x30d5
#define MN_punpcklqdq (MN_vpunpcklqdq + 1)
#define MN_vpunpcklqdq 0x30e3
#define MN_pclmulhqlqdq (MN_vpclmulhqlqdq + 1)
#define MN_vpclmulhqlqdq 0x30ef
#define MN_pclmullqlqdq (MN_vpclmullqlqdq + 1)
#define MN_vpclmullqlqdq 0x30fd
#define MN_pclmulqdq (MN_vpclmulqdq + 1)
#define MN_vpclmulqdq 0x310b
#define MN_vpgatherdq 0x3116
#define MN_vpscatterdq 0x3121
#define MN_vpshrdq 0x312d
#define MN_movntdq (MN_vmovntdq + 1)
#define MN_vmovntdq 0x3135
#define MN_vcvttpd2udq 0x313e
#define MN_vcvtpd2udq 0x314a
#define MN_vcvttph2udq 0x3155
#define MN_vcvtph2udq 0x3161
#define MN_vcvttps2udq 0x316c
#define MN_vcvtps2udq 0x3178
#define MN_vphaddudq 0x3183
#define MN_pmuludq (MN_vpmuludq + 1)
#define MN_vpmuludq 0x318d
#define MN_pmovsxdq (MN_vpmovsxdq + 1)
#define MN_vpmovsxdq 0x3196
#define MN_pmovzxdq (MN_vpmovzxdq + 1)
#define MN_vpmovzxdq 0x31a0
#define MN_vpcomgeq 0x31aa
#define MN_vpcomleq 0x31b3
#define MN_vpcmpnleq 0x31bc
#define MN_vpcmpleq 0x31c6
#define MN_pfcmpeq 0x31cf
#define MN_vpcomfalseq 0x31d7
#define MN_vpcomtrueq 0x31e3
#define MN_vpternlogq 0x31ee
#define MN_vpshlq 0x31f9
#define MN_psllq (MN_vpsllq + 1)
#define MN_vpsllq 0x3200
#define MN_vpmullq 0x3207
#define MN_vprolq 0x320f
#define MN_psrlq (MN_vpsrlq + 1)
#define MN_vpsrlq 0x3216
#define MN_kshiftlq 0x321d
#define MN_vpblendmq 0x3226
#define MN_vptestnmq 0x3230
#define MN_vpcomq 0x323a
#define MN_vpermq 0x3241
#define MN_vptestmq 0x3248
#define MN_kandnq 0x3251
#define MN_vpandnq 0x3258
#define MN_valignq 0x3260
#define MN_vpcmpq 0x3268
#define MN_incsspq 0x326f
#define MN_rdsspq 0x3277
#define MN_vcvttpd2qq 0x327e
#define MN_vcvtpd2qq 0x3289
#define MN_vcvttph2qq 0x3293
#define MN_vcvtph2qq 0x329e
#define MN_vcvttps2qq 0x32a8
#define MN_vcvtps2qq 0x32b3
#define MN_vpcomeqq 0x32bd
#define MN_vpcomneqq 0x32c6
#define MN_vpcmpneqq 0x32d0
#define MN_pcmpeqq (MN_vpcmpeqq + 1)
#define MN_vpcmpeqq 0x32da
#define MN_vpgatherqq 0x32e3
#define MN_vpscatterqq 0x32ee
#define MN_vcvttpd2uqq 0x32fa
#define MN_vcvtpd2uqq 0x3306
#define MN_vcvttph2uqq 0x3311
#define MN_vcvtph2uqq 0x331d
#define MN_vcvttps2uqq 0x3328
#define MN_vcvtps2uqq 0x3334
#define MN_korq 0x333f
#define MN_kxnorq 0x3344
#define MN_vporq 0x334b
#define MN_vprorq 0x3351
#define MN_kxorq 0x3358
#define MN_vpxorq 0x335e
#define MN_pinsrq (MN_vpinsrq + 1)
#define MN_vpinsrq 0x3365
#define MN_kshiftrq 0x336d
#define MN_extrq (MN_pextrq + 1)
#define MN_pextrq (MN_vpextrq + 1)
#define MN_vpextrq 0x3376
#define MN_vpabsq 0x337e
#define MN_vpminsq 0x3385
#define MN_vmovrsq 0x338d
#define MN_vpcompressq 0x3395
#define MN_wrssq 0x33a1
#define MN_wrussq 0x33a7
#define MN_vpmaxsq 0x33ae
#define MN_vp2intersectq 0x33b6
#define MN_vpconflictq 0x33c4
#define MN_vpcomgtq 0x33d0
#define MN_pcmpgtq (MN_vpcmpgtq + 1)
#define MN_vpcmpgtq 0x33d9
#define MN_cltq 0x33e2
#define MN_vpcomltq 0x33e7
#define MN_vpcmpnltq 0x33f0
#define MN_vpcmpltq 0x33fa
#define MN_vpopcntq 0x3403
#define MN_vplzcntq 0x340c
#define MN_movntq 0x3415
#define MN_knotq 0x341c
#define MN_vprotq 0x3422
#define MN_insertq 0x3429
#define MN_vpbroadcastq 0x3431
#define MN_ktestq 0x343e
#define MN_kortestq 0x3445
#define MN_vpcomgeuq 0x344e
#define MN_vpcomleuq 0x3458
#define MN_vpcmpnleuq 0x3462
#define MN_vpcmpleuq 0x346d
#define MN_vpcomfalseuq 0x3477
#define MN_vpcomtrueuq 0x3484
#define MN_vpmadd52huq 0x3490
#define MN_vpmadd52luq 0x349c
#define MN_vpcomuq 0x34a8
#define MN_vpminuq 0x34b0
#define MN_vpcmpuq 0x34b8
#define MN_vpcomequq 0x34c0
#define MN_vpcomnequq 0x34ca
#define MN_vpcmpnequq 0x34d5
#define MN_vpcmpequq 0x34e0
#define MN_vpcomgtuq 0x34ea
#define MN_vpcomltuq 0x34f4
#define MN_vpcmpnltuq 0x34fe
#define MN_vpcmpltuq 0x3509
#define MN_vpmaxuq 0x3513
#define MN_vpsravq 0x351b
#define MN_vpshldvq 0x3523
#define MN_vpshrdvq 0x352c
#define MN_vpsllvq 0x3535
#define MN_vprolvq 0x353d
#define MN_vpsrlvq 0x3545
#define MN_movq (MN_kmovq + 1)
#define MN_kmovq (MN_maskmovq + 3)
#define MN_maskmovq (MN_vpmaskmovq + 2)
#define MN_vpmaskmovq 0x354d
#define MN_vmovq 0x3558
#define MN_vprorvq 0x355e
#define MN_vphaddwq 0x3566
#define MN_vphadduwq 0x356f
#define MN_pmovsxwq (MN_vpmovsxwq + 1)
#define MN_vpmovsxwq 0x3579
#define MN_pmovzxwq (MN_vpmovzxwq + 1)
#define MN_vpmovzxwq 0x3583
#define MN_rex_r 0x358d
#define MN_vmclear 0x3593
#define MN_lar 0x359b
#define MN_sar 0x359f
#define MN_fsubr (MN_pfsubr + 1)
#define MN_pfsubr 0x35a3
#define MN_fisubr 0x35aa
#define MN_rcr 0x35b1
#define MN_vzeroupper 0x35b5
#define MN_enter (MN_sysenter + 3)
#define MN_sysenter 0x35c0
#define MN_shr 0x35c9
#define MN_clr 0x35cd
#define MN_palignr (MN_vpalignr + 1)
#define MN_vpalignr 0x35d1
#define MN_or (MN_aor + 1)
#define MN_aor 0x35da
#define MN_por (MN_vpor + 1)
#define MN_vpor 0x35de
#define MN_ror 0x35e3
#define MN_monitor (MN_umonitor + 1)
#define MN_umonitor 0x35e7
#define MN_frstor 0x35f0
#define MN_xrstor (MN_fxrstor + 1)
#define MN_fxrstor 0x35f7
#define MN_xor (MN_axor + 1)
#define MN_axor 0x35ff
#define MN_pxor (MN_vpxor + 1)
#define MN_vpxor 0x3604
#define MN_verr 0x360a
#define MN_bsr 0x360f
#define MN_ldmxcsr (MN_vldmxcsr + 1)
#define MN_vldmxcsr 0x3613
#define MN_stmxcsr (MN_vstmxcsr + 1)
#define MN_vstmxcsr 0x361c
#define MN_blsr 0x3625
#define MN_rdmsr (MN_urdmsr + 1)
#define MN_urdmsr 0x362a
#define MN_wrmsr (MN_uwrmsr + 1)
#define MN_uwrmsr 0x3631
#define MN_btr 0x3638
#define MN_xcrypt_ctr 0x363c
#define MN_xcryptctr 0x3647
#define MN_ltr 0x3651
#define MN_str 0x3655
#define MN_bextr 0x3659
#define MN_fdivr 0x365f
#define MN_fidivr 0x3665
#define MN_rex_wr 0x366c
#define MN_vcvt2ph2bf8s 0x3673
#define MN_vcvtbiasph2bf8s 0x3680
#define MN_vcvtph2bf8s 0x3690
#define MN_vcvt2ph2hf8s 0x369c
#define MN_vcvtbiasph2hf8s 0x36a9
#define MN_vcvtph2hf8s 0x36b9
#define MN_aas 0x36c5
#define MN_scas 0x36c9
#define MN_das 0x36ce
#define MN_fabs 0x36d2
#define MN_jmpabs 0x36d7
#define MN_movabs 0x36de
#define MN_vcvttbf162ibs 0x36e5
#define MN_vcvtbf162ibs 0x36f3
#define MN_vcvttph2ibs 0x3700
#define MN_vcvtph2ibs 0x370c
#define MN_vcvttps2ibs 0x3717
#define MN_vcvtps2ibs 0x3723
#define MN_vcvttbf162iubs 0x372e
#define MN_vcvtbf162iubs 0x373d
#define MN_vcvttph2iubs 0x374b
#define MN_vcvtph2iubs 0x3758
#define MN_vcvttps2iubs 0x3764
#define MN_vcvtps2iubs 0x3771
#define MN_cs (MN_blcs + 2)
#define MN_blcs 0x377d
#define MN_ds (MN_lds + 1)
#define MN_lds 0x3782
#define MN_enqcmds 0x3786
#define MN_lods 0x378e
#define MN_vpdpbssds 0x3793
#define MN_vp4dpwssds 0x379d
#define MN_vpdpwssds 0x37a8
#define MN_vpdpbusds 0x37b2
#define MN_vpdpwusds 0x37bc
#define MN_vpdpbsuds 0x37c6
#define MN_vpdpwsuds 0x37d0
#define MN_vpdpbuuds 0x37da
#define MN_vpdpwuuds 0x37e4
#define MN_es (MN_les + 1)
#define MN_les 0x37ee
#define MN_xsaves 0x37f2
#define MN_fs (MN_lfs + 1)
#define MN_lfs 0x37f9
#define MN_gs (MN_lkgs + 2)
#define MN_lkgs 0x37fd
#define MN_lgs 0x3802
#define MN_swapgs 0x3806
#define MN_fchs 0x380d
#define MN_vcvttsd2sis 0x3812
#define MN_vcvttss2sis 0x381e
#define MN_vcvttsd2usis 0x382a
#define MN_vcvttss2usis 0x3837
#define MN_js 0x3844
#define MN_encls 0x3847
#define MN_emms (MN_femms + 1)
#define MN_femms 0x384d
#define MN_ins (MN_lwpins + 3)
#define MN_lwpins 0x3853
#define MN_jns 0x385a
#define MN_ccmpns 0x385e
#define MN_wrmsrns 0x3865
#define MN_setns 0x386d
#define MN_ctestns 0x3873
#define MN_setzuns 0x387b
#define MN_cmovns (MN_cfcmovns + 2)
#define MN_cfcmovns 0x3883
#define MN_fcos 0x388c
#define MN_fsincos 0x3891
#define MN_stos 0x3899
#define MN_vfmaddsub231ps 0x389e
#define MN_vfmsub231ps 0x38ad
#define MN_vfnmsub231ps 0x38b9
#define MN_vfmsubadd231ps 0x38c6
#define MN_vfmadd231ps 0x38d5
#define MN_vfnmadd231ps 0x38e1
#define MN_vfmaddsub132ps 0x38ee
#define MN_vfmsub132ps 0x38fd
#define MN_vfnmsub132ps 0x3909
#define MN_vfmsubadd132ps 0x3916
#define MN_vfmadd132ps 0x3925
#define MN_vfnmadd132ps 0x3931
#define MN_tmmultf32ps (MN_ttmmultf32ps + 1)
#define MN_ttmmultf32ps 0x393e
#define MN_vcvtneebf162ps 0x394b
#define MN_vbcstnebf162ps 0x395a
#define MN_vcvtneobf162ps 0x3969
#define MN_cvtpd2ps (MN_vcvtpd2ps + 1)
#define MN_vcvtpd2ps 0x3978
#define MN_tcvtrowd2ps 0x3982
#define MN_vcvtneeph2ps 0x398e
#define MN_vcvtneoph2ps 0x399b
#define MN_vcvtph2ps 0x39a8
#define MN_vbcstnesh2ps 0x39b2
#define MN_vpermi2ps 0x39bf
#define MN_cvtpi2ps 0x39c9
#define MN_vpermil2ps 0x39d2
#define MN_vexp2ps 0x39dd
#define MN_cvtdq2ps (MN_vcvtdq2ps + 1)
#define MN_vcvtdq2ps 0x39e5
#define MN_vcvtudq2ps 0x39ef
#define MN_vcvtqq2ps 0x39fa
#define MN_vcvtuqq2ps 0x3a04
#define MN_vpermt2ps 0x3a0f
#define MN_vfmaddsub213ps 0x3a19
#define MN_vfmsub213ps 0x3a28
#define MN_vfnmsub213ps 0x3a34
#define MN_vfmsubadd213ps 0x3a41
#define MN_vfmadd213ps 0x3a50
#define MN_vfnmadd213ps 0x3a5c
#define MN_vrcp14ps 0x3a69
#define MN_vrsqrt14ps 0x3a72
#define MN_tdpbf16ps (MN_ttdpbf16ps + 1)
#define MN_ttdpbf16ps 0x3a7d
#define MN_vdpbf16ps 0x3a88
#define MN_tcmmrlfp16ps (MN_ttcmmrlfp16ps + 1)
#define MN_ttcmmrlfp16ps 0x3a92
#define MN_tcmmimfp16ps (MN_tconjtcmmimfp16ps + 5)
#define MN_tconjtcmmimfp16ps 0x3aa0
#define MN_ttcmmimfp16ps 0x3ab2
#define MN_tdpfp16ps (MN_ttdpfp16ps + 1)
#define MN_ttdpfp16ps 0x3ac0
#define MN_vrcp28ps 0x3acb
#define MN_vrsqrt28ps 0x3ad4
#define MN_tdphbf8ps 0x3adf
#define MN_tdpbf8ps 0x3ae9
#define MN_tdpbhf8ps 0x3af2
#define MN_tdphf8ps 0x3afc
#define MN_movaps (MN_vmovaps + 1)
#define MN_vmovaps 0x3b05
#define MN_subps (MN_addsubps + 3)
#define MN_addsubps (MN_vfmaddsubps + 3)
#define MN_vfmaddsubps 0x3b0d
#define MN_vaddsubps 0x3b19
#define MN_hsubps (MN_vhsubps + 1)
#define MN_vhsubps 0x3b23
#define MN_vfmsubps 0x3b2b
#define MN_vfnmsubps 0x3b34
#define MN_vsubps 0x3b3e
#define MN_vgatherpf0dps 0x3b45
#define MN_vscatterpf0dps 0x3b53
#define MN_vgatherpf1dps 0x3b62
#define MN_vscatterpf1dps 0x3b70
#define MN_addps (MN_vfmsubaddps + 6)
#define MN_vfmsubaddps 0x3b7f
#define MN_haddps (MN_vhaddps + 1)
#define MN_vhaddps 0x3b8b
#define MN_v4fmaddps 0x3b93
#define MN_vfmaddps 0x3b9d
#define MN_v4fnmaddps 0x3ba6
#define MN_vfnmaddps 0x3bb1
#define MN_vaddps 0x3bbb
#define MN_andps (MN_vexpandps + 4)
#define MN_vexpandps 0x3bc2
#define MN_vandps 0x3bcc
#define MN_blendps (MN_vblendps + 1)
#define MN_vblendps 0x3bd3
#define MN_roundps (MN_vroundps + 1)
#define MN_vroundps 0x3bdc
#define MN_vgatherdps 0x3be5
#define MN_vscatterdps 0x3bf0
#define MN_cmpunordps (MN_vcmpunordps + 1)
#define MN_vcmpunordps 0x3bfc
#define MN_cmpordps (MN_vcmpordps + 1)
#define MN_vcmpordps 0x3c08
#define MN_vreduceps 0x3c12
#define MN_vrangeps 0x3c1c
#define MN_vcmpngeps 0x3c25
#define MN_vcmpgeps 0x3c2f
#define MN_vrndscaleps 0x3c38
#define MN_cmpnleps (MN_vcmpnleps + 1)
#define MN_vcmpnleps 0x3c44
#define MN_cmpleps (MN_vcmpleps + 1)
#define MN_vcmpleps 0x3c4e
#define MN_vcmpfalseps 0x3c57
#define MN_vcmptrueps 0x3c63
#define MN_vscalefps 0x3c6e
#define MN_shufps (MN_vshufps + 1)
#define MN_vshufps 0x3c78
#define MN_unpckhps (MN_vunpckhps + 1)
#define MN_vunpckhps 0x3c80
#define MN_movlhps (MN_vmovlhps + 1)
#define MN_vmovlhps 0x3c8a
#define MN_vdpphps 0x3c93
#define MN_movhps (MN_vmovhps + 1)
#define MN_vmovhps 0x3c9b
#define MN_movmskps (MN_vmovmskps + 1)
#define MN_vmovmskps 0x3ca3
#define MN_movhlps (MN_vmovhlps + 1)
#define MN_vmovhlps 0x3cad
#define MN_vpermilps 0x3cb6
#define MN_unpcklps (MN_vunpcklps + 1)
#define MN_vunpcklps 0x3cc0
#define MN_mulps (MN_vmulps + 1)
#define MN_vmulps 0x3cca
#define MN_movlps (MN_vmovlps + 1)
#define MN_vmovlps 0x3cd1
#define MN_cmps (MN_ccmps + 1)
#define MN_ccmps 0x3cd9
#define MN_vblendmps 0x3cdf
#define MN_vfixupimmps 0x3ce9
#define MN_vpermps 0x3cf5
#define MN_andnps (MN_vandnps + 1)
#define MN_vandnps 0x3cfd
#define MN_minps (MN_vminps + 1)
#define MN_vminps 0x3d05
#define MN_seamops 0x3d0c
#define MN_rcpps (MN_vrcpps + 1)
#define MN_vrcpps 0x3d14
#define MN_dpps (MN_vdpps + 1)
#define MN_vdpps 0x3d1b
#define MN_cmpps (MN_vcmpps + 1)
#define MN_vcmpps 0x3d21
#define MN_vgetexpps 0x3d28
#define MN_vgatherpf0qps 0x3d32
#define MN_vscatterpf0qps 0x3d40
#define MN_vgatherpf1qps 0x3d4f
#define MN_vscatterpf1qps 0x3d5d
#define MN_vcmpunord_qps 0x3d6c
#define MN_vcmpord_qps 0x3d7a
#define MN_cmpneqps (MN_vcmpneqps + 1)
#define MN_vcmpneqps 0x3d86
#define MN_cmpeqps (MN_vcmpeqps + 1)
#define MN_vcmpeqps 0x3d90
#define MN_vcmpge_oqps 0x3d99
#define MN_vcmple_oqps 0x3da5
#define MN_vcmpfalse_oqps 0x3db1
#define MN_vcmpneq_oqps 0x3dc0
#define MN_vcmpeq_oqps 0x3dcd
#define MN_vcmpgt_oqps 0x3dd9
#define MN_vcmplt_oqps 0x3de5
#define MN_vgatherqps 0x3df1
#define MN_vscatterqps 0x3dfc
#define MN_vcmpnge_uqps 0x3e08
#define MN_vcmpnle_uqps 0x3e15
#define MN_vcmptrue_uqps 0x3e22
#define MN_vcmpneq_uqps 0x3e30
#define MN_vcmpeq_uqps 0x3e3d
#define MN_vcmpngt_uqps 0x3e49
#define MN_vcmpnlt_uqps 0x3e56
#define MN_orps (MN_vorps + 1)
#define MN_vorps 0x3e63
#define MN_xorps (MN_vxorps + 1)
#define MN_vxorps 0x3e69
#define MN_vcmpunord_sps 0x3e70
#define MN_vcmpord_sps 0x3e7e
#define MN_vcmpge_osps 0x3e8a
#define MN_vcmple_osps 0x3e96
#define MN_vcmpfalse_osps 0x3ea2
#define MN_vcmpneq_osps 0x3eb1
#define MN_vcmpeq_osps 0x3ebe
#define MN_vcmpgt_osps 0x3eca
#define MN_vcmplt_osps 0x3ed6
#define MN_vfpclassps 0x3ee2
#define MN_vcompressps 0x3eed
#define MN_vcmpnge_usps 0x3ef9
#define MN_vcmpnle_usps 0x3f06
#define MN_vcmptrue_usps 0x3f13
#define MN_vcmpneq_usps 0x3f21
#define MN_vcmpeq_usps 0x3f2e
#define MN_vcmpngt_usps 0x3f3a
#define MN_vcmpnlt_usps 0x3f47
#define MN_extractps (MN_vextractps + 1)
#define MN_vextractps 0x3f54
#define MN_vcmpngtps 0x3f5f
#define MN_vcmpgtps 0x3f69
#define MN_cmpnltps (MN_vcmpnltps + 1)
#define MN_vcmpnltps 0x3f72
#define MN_cmpltps (MN_vcmpltps + 1)
#define MN_vcmpltps 0x3f7c
#define MN_vgetmantps 0x3f85
#define MN_movntps (MN_vmovntps + 1)
#define MN_vmovntps 0x3f90
#define MN_insertps (MN_vinsertps + 1)
#define MN_vinsertps 0x3f99
#define MN_sqrtps (MN_rsqrtps + 1)
#define MN_rsqrtps (MN_vrsqrtps + 1)
#define MN_vrsqrtps 0x3fa3
#define MN_vsqrtps 0x3fac
#define MN_vtestps 0x3fb4
#define MN_movups (MN_vmovups + 1)
#define MN_vmovups 0x3fbc
#define MN_blendvps (MN_vblendvps + 1)
#define MN_vblendvps 0x3fc4
#define MN_divps (MN_vdivps + 1)
#define MN_vdivps 0x3fce
#define MN_vmaskmovps 0x3fd5
#define MN_maxps (MN_vminmaxps + 4)
#define MN_vminmaxps 0x3fe0
#define MN_vmaxps 0x3fea
#define MN_vfrczps 0x3ff1
#define MN_vcvttpd2dqs 0x3ff9
#define MN_vcvttps2dqs 0x4005
#define MN_vcvttpd2udqs 0x4011
#define MN_vcvttps2udqs 0x401e
#define MN_vcvttpd2qqs 0x402b
#define MN_vcvttps2qqs 0x4037
#define MN_vcvttpd2uqqs 0x4043
#define MN_vcvttps2uqqs 0x4050
#define MN_t2rpntlvwz0rs 0x405d
#define MN_t2rpntlvwz1rs 0x406b
#define MN_tileloaddrs 0x4079
#define MN_xrstors 0x4085
#define MN_movrs 0x408d
#define MN_ss (MN_vfmsub231ss + 9)
#define MN_vfmsub231ss 0x4093
#define MN_vfnmsub231ss 0x409f
#define MN_vfmadd231ss 0x40ac
#define MN_vfnmadd231ss 0x40b8
#define MN_vfmsub132ss 0x40c5
#define MN_vfnmsub132ss 0x40d1
#define MN_vfmadd132ss 0x40de
#define MN_vfnmadd132ss 0x40ea
#define MN_cvtsd2ss (MN_vcvtsd2ss + 1)
#define MN_vcvtsd2ss 0x40f7
#define MN_vcvtsh2ss 0x4101
#define MN_cvtsi2ss (MN_vcvtsi2ss + 1)
#define MN_vcvtsi2ss 0x410b
#define MN_vcvtusi2ss 0x4115
#define MN_vfmsub213ss 0x4120
#define MN_vfnmsub213ss 0x412c
#define MN_vfmadd213ss 0x4139
#define MN_vfnmadd213ss 0x4145
#define MN_vrcp14ss 0x4152
#define MN_vrsqrt14ss 0x415b
#define MN_vrcp28ss 0x4166
#define MN_vrsqrt28ss 0x416f
#define MN_subss (MN_vfmsubss + 3)
#define MN_vfmsubss 0x417a
#define MN_vfnmsubss 0x4183
#define MN_vsubss 0x418d
#define MN_addss (MN_v4fmaddss + 4)
#define MN_v4fmaddss 0x4194
#define MN_vfmaddss 0x419e
#define MN_v4fnmaddss 0x41a7
#define MN_vfnmaddss 0x41b2
#define MN_vaddss 0x41bc
#define MN_roundss (MN_vroundss + 1)
#define MN_vroundss 0x41c3
#define MN_cmpunordss (MN_vcmpunordss + 1)
#define MN_vcmpunordss 0x41cc
#define MN_cmpordss (MN_vcmpordss + 1)
#define MN_vcmpordss 0x41d8
#define MN_vreducess 0x41e2
#define MN_vrangess 0x41ec
#define MN_vcmpngess 0x41f5
#define MN_vcmpgess 0x41ff
#define MN_vrndscaless 0x4208
#define MN_cmpnless (MN_vcmpnless + 1)
#define MN_vcmpnless 0x4214
#define MN_cmpless (MN_vcmpless + 1)
#define MN_vcmpless 0x421e
#define MN_vcmpfalsess 0x4227
#define MN_vcmptruess 0x4233
#define MN_vscalefss 0x423e
#define MN_comiss (MN_ucomiss + 1)
#define MN_ucomiss (MN_vucomiss + 1)
#define MN_vucomiss 0x4248
#define MN_vcomiss 0x4251
#define MN_lss (MN_mulss + 2)
#define MN_mulss (MN_vmulss + 1)
#define MN_vmulss 0x4259
#define MN_vfixupimmss 0x4260
#define MN_minss (MN_vminss + 1)
#define MN_vminss 0x426c
#define MN_rcpss (MN_vrcpss + 1)
#define MN_vrcpss 0x4273
#define MN_cmpss (MN_vcmpss + 1)
#define MN_vcmpss 0x427a
#define MN_vgetexpss 0x4281
#define MN_vcmpunord_qss 0x428b
#define MN_vcmpord_qss 0x4299
#define MN_cmpneqss (MN_vcmpneqss + 1)
#define MN_vcmpneqss 0x42a5
#define MN_cmpeqss (MN_vcmpeqss + 1)
#define MN_vcmpeqss 0x42af
#define MN_vcmpge_oqss 0x42b8
#define MN_vcmple_oqss 0x42c4
#define MN_vcmpfalse_oqss 0x42d0
#define MN_vcmpneq_oqss 0x42df
#define MN_vcmpeq_oqss 0x42ec
#define MN_vcmpgt_oqss 0x42f8
#define MN_vcmplt_oqss 0x4304
#define MN_vcmpnge_uqss 0x4310
#define MN_vcmpnle_uqss 0x431d
#define MN_vcmptrue_uqss 0x432a
#define MN_vcmpneq_uqss 0x4338
#define MN_vcmpeq_uqss 0x4345
#define MN_vcmpngt_uqss 0x4351
#define MN_vcmpnlt_uqss 0x435e
#define MN_vcmpunord_sss 0x436b
#define MN_vcmpord_sss 0x4379
#define MN_vcmpge_osss 0x4385
#define MN_vcmple_osss 0x4391
#define MN_vcmpfalse_osss 0x439d
#define MN_vcmpneq_osss 0x43ac
#define MN_vcmpeq_osss 0x43b9
#define MN_vcmpgt_osss 0x43c5
#define MN_vcmplt_osss 0x43d1
#define MN_vfpclassss 0x43dd
#define MN_vcmpnge_usss 0x43e8
#define MN_vcmpnle_usss 0x43f5
#define MN_vcmptrue_usss 0x4402
#define MN_vcmpneq_usss 0x4410
#define MN_vcmpeq_usss 0x441d
#define MN_vcmpngt_usss 0x4429
#define MN_vcmpnlt_usss 0x4436
#define MN_vcmpngtss 0x4443
#define MN_vcmpgtss 0x444d
#define MN_cmpnltss (MN_vcmpnltss + 1)
#define MN_vcmpnltss 0x4456
#define MN_cmpltss (MN_vcmpltss + 1)
#define MN_vcmpltss 0x4460
#define MN_vgetmantss 0x4469
#define MN_movntss 0x4474
#define MN_sqrtss (MN_rsqrtss + 1)
#define MN_rsqrtss (MN_vrsqrtss + 1)
#define MN_vrsqrtss 0x447c
#define MN_vsqrtss 0x4485
#define MN_vbroadcastss 0x448d
#define MN_divss (MN_vdivss + 1)
#define MN_vdivss 0x449a
#define MN_movss (MN_vmovss + 1)
#define MN_vmovss 0x44a1
#define MN_maxss (MN_vminmaxss + 4)
#define MN_vminmaxss 0x44a8
#define MN_vmaxss 0x44b2
#define MN_vucomxss 0x44b9
#define MN_vcomxss 0x44c2
#define MN_vfrczss 0x44ca
#define MN_bts 0x44d2
#define MN_erets 0x44d6
#define MN_sets 0x44dc
#define MN_clts 0x44e1
#define MN_ctests 0x44e6
#define MN_outs 0x44ed
#define MN_setzus 0x44f2
#define MN_movs (MN_cmovs + 1)
#define MN_cmovs (MN_cfcmovs + 2)
#define MN_cfcmovs 0x44f9
#define MN_fldl2t 0x4501
#define MN_xlat 0x4508
#define MN_bt 0x450d
#define MN_fxtract 0x4510
#define MN_lgdt 0x4518
#define MN_sgdt 0x451d
#define MN_lidt 0x4522
#define MN_sidt 0x4527
#define MN_fldt 0x452c
#define MN_lldt 0x4531
#define MN_sldt 0x4536
#define MN_ret (MN_iret + 1)
#define MN_iret (MN_uiret + 1)
#define MN_uiret 0x453b
#define MN_lret 0x4541
#define MN_seamret 0x4546
#define MN_sysret 0x454e
#define MN_hreset 0x4555
#define MN_pfcmpgt 0x455c
#define MN_ht 0x4564
#define MN_wait (MN_fwait + 1)
#define MN_fwait 0x4567
#define MN_mwait (MN_umwait + 1)
#define MN_umwait 0x456d
#define MN_mcommit 0x4574
#define MN_finit 0x457c
#define MN_skinit 0x4582
#define MN_fninit 0x4589
#define MN_vmgexit 0x4590
#define MN_sysexit 0x4598
#define MN_hlt 0x45a0
#define MN_popcnt 0x45a4
#define MN_lzcnt 0x45ab
#define MN_tzcnt 0x45b1
#define MN_hnt 0x45b7
#define MN_int (MN_frndint + 4)
#define MN_frndint 0x45bb
#define MN_not 0x45c3
#define MN_invept 0x45c7
#define MN_ccmpt 0x45ce
#define MN_xsaveopt 0x45d4
#define MN_clflushopt 0x45dd
#define MN_fstpt 0x45e8
#define MN_xabort 0x45ee
#define MN_fsqrt 0x45f5
#define MN_pfrsqrt 0x45fb
#define MN_aesdeclast (MN_vaesdeclast + 1)
#define MN_vaesdeclast 0x4603
#define MN_aesenclast (MN_vaesenclast + 1)
#define MN_vaesenclast 0x460f
#define MN_test (MN_ptest + 1)
#define MN_ptest (MN_vptest + 1)
#define MN_vptest 0x461b
#define MN_xtest 0x4622
#define MN_fst 0x4628
#define MN_fist 0x462c
#define MN_rdmsrlist 0x4631
#define MN_wrmsrlist 0x463b
#define MN_aeskeygenassist (MN_vaeskeygenassist + 1)
#define MN_vaeskeygenassist 0x4645
#define MN_vmptrst 0x4656
#define MN_ftst 0x465e
#define MN_rmpadjust 0x4663
#define MN_ctestt 0x466d
#define MN_out 0x4674
#define MN_pext 0x4678
#define MN_bndcu 0x467d
#define MN_enclu 0x4683
#define MN_fcmovnu 0x4689
#define MN_lddqu (MN_vlddqu + 1)
#define MN_vlddqu 0x4691
#define MN_movdqu (MN_maskmovdqu + 4)
#define MN_maskmovdqu (MN_vmaskmovdqu + 1)
#define MN_vmaskmovdqu 0x4698
#define MN_vmovdqu 0x46a4
#define MN_rdpkru 0x46ac
#define MN_wrpkru 0x46b3
#define MN_rdpru 0x46ba
#define MN_eretu 0x46c0
#define MN_fcmovu 0x46c6
#define MN_imulzu 0x46cd
#define MN_xgetbv 0x46d4
#define MN_xsetbv 0x46db
#define MN_div (MN_fdiv + 1)
#define MN_fdiv 0x46e2
#define MN_idiv (MN_fidiv + 1)
#define MN_fidiv 0x46e7
#define MN_enclv 0x46ed
#define MN_fldenv 0x46f3
#define MN_fstenv 0x46fa
#define MN_fnstenv 0x4701
#define MN_mov (MN_vpcmov + 3)
#define MN_vpcmov 0x4709
#define MN_bndmov 0x4710
#define MN_smov 0x4717
#define MN_rex_w 0x471c
#define MN_vcvttph2w 0x4722
#define MN_vcvtph2w 0x472c
#define MN_vpermi2w 0x4735
#define MN_vpmovm2w 0x473e
#define MN_vpermt2w 0x4747
#define MN_vpshaw 0x4750
#define MN_psraw (MN_vpsraw + 1)
#define MN_vpsraw 0x4757
#define MN_vphsubbw 0x475e
#define MN_cbw 0x4767
#define MN_psadbw (MN_vdbpsadbw + 3)
#define MN_vdbpsadbw 0x476b
#define MN_mpsadbw (MN_vmpsadbw + 1)
#define MN_vmpsadbw 0x4775
#define MN_vpsadbw 0x477e
#define MN_vphaddbw 0x4786
#define MN_punpckhbw (MN_vpunpckhbw + 1)
#define MN_vpunpckhbw 0x478f
#define MN_kunpckbw 0x479a
#define MN_punpcklbw (MN_vpunpcklbw + 1)
#define MN_vpunpcklbw 0x47a3
#define MN_vphaddubw 0x47ae
#define MN_phsubw (MN_vphsubw + 1)
#define MN_vphsubw 0x47b8
#define MN_psubw (MN_vpsubw + 1)
#define MN_vpsubw 0x47c0
#define MN_pmovsxbw (MN_vpmovsxbw + 1)
#define MN_vpmovsxbw 0x47c7
#define MN_pmovzxbw (MN_vpmovzxbw + 1)
#define MN_vpmovzxbw 0x47d1
#define MN_fldcw 0x47db
#define MN_fstcw 0x47e1
#define MN_fnstcw 0x47e7
#define MN_phaddw (MN_vphaddw + 1)
#define MN_vphaddw 0x47ee
#define MN_kaddw 0x47f6
#define MN_paddw (MN_vpaddw + 1)
#define MN_vpaddw 0x47fc
#define MN_vpshldw 0x4803
#define MN_kandw 0x480b
#define MN_vpexpandw 0x4811
#define MN_pblendw (MN_vpblendw + 1)
#define MN_vpblendw 0x481b
#define MN_vpshrdw 0x4824
#define MN_packssdw (MN_vpackssdw + 1)
#define MN_vpackssdw 0x482c
#define MN_packusdw (MN_vpackusdw + 1)
#define MN_vpackusdw 0x4836
#define MN_vpmovusdw 0x4840
#define MN_vpmovsdw 0x484a
#define MN_vpmovdw 0x4853
#define MN_vpcomgew 0x485b
#define MN_vpcomlew 0x4864
#define MN_vpcmpnlew 0x486d
#define MN_vpcmplew 0x4877
#define MN_vpcomfalsew 0x4880
#define MN_vpcomtruew 0x488c
#define MN_pi2fw 0x4897
#define MN_pshufw 0x489d
#define MN_pavgw (MN_vpavgw + 1)
#define MN_vpavgw 0x48a4
#define MN_prefetchw 0x48ab
#define MN_pshufhw (MN_vpshufhw + 1)
#define MN_vpshufhw 0x48b5
#define MN_pmulhw (MN_vpmulhw + 1)
#define MN_vpmulhw 0x48be
#define MN_pf2iw 0x48c6
#define MN_pshuflw (MN_vpshuflw + 1)
#define MN_vpshuflw 0x48cc
#define MN_vpshlw 0x48d5
#define MN_psllw (MN_vpsllw + 1)
#define MN_vpsllw 0x48dc
#define MN_pmullw (MN_vpmullw + 1)
#define MN_vpmullw 0x48e3
#define MN_psrlw (MN_vpsrlw + 1)
#define MN_vpsrlw 0x48eb
#define MN_kshiftlw 0x48f2
#define MN_vpblendmw 0x48fb
#define MN_vptestnmw 0x4905
#define MN_vpcomw 0x490f
#define MN_vpermw 0x4916
#define MN_vptestmw 0x491d
#define MN_kandnw 0x4926
#define MN_psignw (MN_vpsignw + 1)
#define MN_vpsignw 0x492d
#define MN_tilemovrow 0x4935
#define MN_vpcmpw 0x4940
#define MN_vpcomeqw 0x4947
#define MN_vpcomneqw 0x4950
#define MN_vpcmpneqw 0x495a
#define MN_pcmpeqw (MN_vpcmpeqw + 1)
#define MN_vpcmpeqw 0x4964
#define MN_vpmovusqw 0x496d
#define MN_vpmovsqw 0x4977
#define MN_vpmovqw 0x4980
#define MN_verw 0x4988
#define MN_pmulhrw 0x498d
#define MN_korw 0x4995
#define MN_kxnorw 0x499a
#define MN_kxorw 0x49a1
#define MN_pinsrw (MN_vpinsrw + 1)
#define MN_vpinsrw 0x49a7
#define MN_kshiftrw 0x49af
#define MN_pextrw (MN_vpextrw + 1)
#define MN_vpextrw 0x49b8
#define MN_pabsw (MN_vpabsw + 1)
#define MN_vpabsw 0x49c0
#define MN_pmaddubsw (MN_vpmaddubsw + 1)
#define MN_vpmaddubsw 0x49c7
#define MN_phsubsw (MN_vphsubsw + 1)
#define MN_vphsubsw 0x49d2
#define MN_psubsw (MN_vpsubsw + 1)
#define MN_vpsubsw 0x49db
#define MN_phaddsw (MN_vphaddsw + 1)
#define MN_vphaddsw 0x49e3
#define MN_paddsw (MN_vpaddsw + 1)
#define MN_vpaddsw 0x49ec
#define MN_lmsw 0x49f4
#define MN_smsw 0x49f9
#define MN_pminsw (MN_vpminsw + 1)
#define MN_vpminsw 0x49fe
#define MN_pmulhrsw (MN_vpmulhrsw + 1)
#define MN_vpmulhrsw 0x4a06
#define MN_vmovrsw 0x4a10
#define MN_vpcompressw 0x4a18
#define MN_fstsw 0x4a24
#define MN_fnstsw 0x4a2a
#define MN_psubusw (MN_vpsubusw + 1)
#define MN_vpsubusw 0x4a31
#define MN_paddusw (MN_vpaddusw + 1)
#define MN_vpaddusw 0x4a3a
#define MN_movsw 0x4a43
#define MN_pmaxsw (MN_vpmaxsw + 1)
#define MN_vpmaxsw 0x4a49
#define MN_cbtw 0x4a51
#define MN_vpcomgtw 0x4a56
#define MN_pcmpgtw (MN_vpcmpgtw + 1)
#define MN_vpcmpgtw 0x4a5f
#define MN_vpcomltw 0x4a68
#define MN_vpcmpnltw 0x4a71
#define MN_vpcmpltw 0x4a7b
#define MN_vpopcntw 0x4a84
#define MN_knotw 0x4a8d
#define MN_vprotw 0x4a93
#define MN_vpbroadcastw 0x4a9a
#define MN_ktestw 0x4aa7
#define MN_kortestw 0x4aae
#define MN_vcvttph2uw 0x4ab7
#define MN_vcvtph2uw 0x4ac2
#define MN_vpcomgeuw 0x4acc
#define MN_vpcomleuw 0x4ad6
#define MN_vpcmpnleuw 0x4ae0
#define MN_vpcmpleuw 0x4aeb
#define MN_vpcomfalseuw 0x4af5
#define MN_vpcomtrueuw 0x4b02
#define MN_pmulhuw (MN_vpmulhuw + 1)
#define MN_vpmulhuw 0x4b0e
#define MN_vpcomuw 0x4b17
#define MN_pminuw (MN_vpminuw + 1)
#define MN_vpminuw 0x4b1f
#define MN_vpcmpuw 0x4b27
#define MN_vpcomequw 0x4b2f
#define MN_vpcomnequw 0x4b39
#define MN_vpcmpnequw 0x4b44
#define MN_vpcmpequw 0x4b4f
#define MN_phminposuw (MN_vphminposuw + 1)
#define MN_vphminposuw 0x4b59
#define MN_vpcomgtuw 0x4b65
#define MN_vpcomltuw 0x4b6f
#define MN_vpcmpnltuw 0x4b79
#define MN_vpcmpltuw 0x4b84
#define MN_pmaxuw (MN_vpmaxuw + 1)
#define MN_vpmaxuw 0x4b8e
#define MN_vpsravw 0x4b96
#define MN_vpshldvw 0x4b9e
#define MN_vpshrdvw 0x4ba7
#define MN_vpsllvw 0x4bb0
#define MN_vpsrlvw 0x4bb8
#define MN_kmovw 0x4bc0
#define MN_vmovw 0x4bc6
#define MN_vpmacsww 0x4bcc
#define MN_vpmacssww 0x4bd5
#define MN_movzw 0x4bdf
#define MN_rex_x 0x4be5
#define MN_fyl2x 0x4beb
#define MN_rex64x 0x4bf1
#define MN_vcvtneps2bf16x 0x4bf8
#define MN_vfpclassbf16x 0x4c07
#define MN_vcvtph2bf8x 0x4c15
#define MN_vcvtph2hf8x 0x4c21
#define MN_pfmax 0x4c2d
#define MN_adcx 0x4c33
#define MN_bndldx 0x4c38
#define MN_vfpclasspdx 0x4c3f
#define MN_fclex 0x4c4b
#define MN_fnclex 0x4c51
#define MN_rex 0x4c58
#define MN_vcvtpd2phx 0x4c5c
#define MN_vcvtdq2phx 0x4c67
#define MN_vcvtudq2phx 0x4c72
#define MN_vcvtqq2phx 0x4c7e
#define MN_vcvtuqq2phx 0x4c89
#define MN_vcvt2ps2phx 0x4c95
#define MN_vcvtps2phx 0x4ca1
#define MN_vfpclassphx 0x4cac
#define MN_shlx 0x4cb8
#define MN_mulx 0x4cbd
#define MN_adox 0x4cc2
#define MN_vcvttpd2dqx 0x4cc7
#define MN_vcvtpd2dqx 0x4cd3
#define MN_vcvttpd2udqx 0x4cde
#define MN_vcvtpd2udqx 0x4ceb
#define MN_rex_rx 0x4cf7
#define MN_sarx 0x4cfe
#define MN_shrx 0x4d03
#define MN_rorx 0x4d08
#define MN_monitorx 0x4d0d
#define MN_rex_wrx 0x4d16
#define MN_vcvtph2bf8sx 0x4d1e
#define MN_vcvtph2hf8sx 0x4d2b
#define MN_vcvtpd2psx 0x4d38
#define MN_vcvtph2psx 0x4d43
#define MN_vcvtqq2psx 0x4d4e
#define MN_vcvtuqq2psx 0x4d59
#define MN_vfpclasspsx 0x4d65
#define MN_vcvttpd2dqsx 0x4d71
#define MN_vcvttpd2udqsx 0x4d7e
#define MN_movsx 0x4d8c
#define MN_mwaitx 0x4d92
#define MN_bndstx 0x4d99
#define MN_rex_wx 0x4da0
#define MN_rexx 0x4da7
#define MN_vcvtps2phxx 0x4dac
#define MN_movzx 0x4db8
#define MN_rex64y 0x4dbe
#define MN_vcvtneps2bf16y 0x4dc5
#define MN_vfpclassbf16y 0x4dd4
#define MN_vcvtph2bf8y 0x4de2
#define MN_vcvtph2hf8y 0x4dee
#define MN_vfpclasspdy 0x4dfa
#define MN_loadiwkey 0x4e06
#define MN_vcvtpd2phy 0x4e10
#define MN_vcvtdq2phy 0x4e1b
#define MN_vcvtudq2phy 0x4e26
#define MN_vcvtqq2phy 0x4e32
#define MN_vcvtuqq2phy 0x4e3d
#define MN_vfpclassphy 0x4e49
#define MN_vcvttpd2dqy 0x4e55
#define MN_vcvtpd2dqy 0x4e61
#define MN_vcvttpd2udqy 0x4e6c
#define MN_vcvtpd2udqy 0x4e79
#define MN_rmpquery 0x4e85
#define MN_vcvtph2bf8sy 0x4e8e
#define MN_vcvtph2hf8sy 0x4e9b
#define MN_clrssbsy 0x4ea8
#define MN_setssbsy 0x4eb1
#define MN_vcvtpd2psy 0x4eba
#define MN_vcvtqq2psy 0x4ec5
#define MN_vcvtuqq2psy 0x4ed0
#define MN_vfpclasspsy 0x4edc
#define MN_vcvttpd2dqsy 0x4ee8
#define MN_vcvttpd2udqsy 0x4ef5
#define MN_rex64xy 0x4f03
#define MN_rexy 0x4f0b
#define MN_vcvtps2phxy 0x4f10
#define MN_rexxy 0x4f1c
#define MN_rex64z 0x4f22
#define MN_vfpclassbf16z 0x4f29
#define MN_fldz 0x4f37
#define MN_vfpclasspdz 0x4f3c
#define MN_vcvtpd2phz 0x4f48
#define MN_vcvtqq2phz 0x4f53
#define MN_vcvtuqq2phz 0x4f5e
#define MN_vfpclassphz 0x4f6a
#define MN_jz 0x4f76
#define MN_jnz 0x4f79
#define MN_repnz 0x4f7d
#define MN_ccmpnz 0x4f83
#define MN_loopnz 0x4f8a
#define MN_setnz 0x4f91
#define MN_ctestnz 0x4f97
#define MN_setzunz 0x4f9f
#define MN_cmovnz (MN_cfcmovnz + 2)
#define MN_cfcmovnz 0x4fa7
#define MN_repz 0x4fb0
#define MN_ccmpz 0x4fb5
#define MN_loopz 0x4fbb
#define MN_vfpclasspsz 0x4fc1
#define MN_setz 0x4fcd
#define MN_ctestz 0x4fd2
#define MN_setzuz 0x4fd9
#define MN_cmovz (MN_cfcmovz + 2)
#define MN_cfcmovz 0x4fe0
#define MN_rex64xz 0x4fe8
#define MN_jecxz 0x4ff0
#define MN_jcxz 0x4ff6
#define MN_jrcxz 0x4ffb
#define MN_rexz 0x5001
#define MN_rexxz 0x5006
#define MN_rex64yz 0x500c
#define MN_rex64xyz 0x5014
#define MN_rexyz 0x501d
#define MN_rexxyz 0x5023
#define MN__disp32_ 0x502a
#define MN__rex2_ 0x5033
#define MN__vex2_ 0x503a
#define MN__vex3_ 0x5041
#define MN__disp16_ 0x5048
#define MN__disp8_ 0x5051
#define MN__load_ 0x5059
#define MN__store_ 0x5060
#define MN__nooptimize_ 0x5068
#define MN__nf_ 0x5075
#define MN__noimm8s_ 0x507a
#define MN__rex_ 0x5084
#define MN__evex_ 0x508a
#define MN__vex_ 0x5091
#define MN__insn 0x5097
